import SQLite from "react-native-sqlite-storage";
SQLite.DEBUG(true);
SQLite.enablePromise(true);

const database_name = "Reactoffline.db";
const database_version = "1.0";
const database_displayname = "SQLite React Offline Database";
const database_size = 200000;

export default class Database {

  initDB() {
    let db;
    return new Promise((resolve) => {
      console.log("Plugin integrity check ...");
      SQLite.echoTest()
        .then(() => {
          console.log("Integrity check passed ...");
          console.log("Opening database ...");
          SQLite.openDatabase(
            database_name,
            database_version,
            database_displayname,
            database_size
          )
            .then(DB => {
              db = DB;
              console.log("Database OPEN");
              db.executeSql('SELECT 1 FROM pendingSubtasks LIMIT 1').then(() => {
                console.log("Database is ready ... executing query ...");
              }).catch((error) => {
                console.log("Received error: ", error);
                console.log("Database not yet ready ... populating data");

                db.transaction((tx) => {
                  tx.executeSql('CREATE TABLE IF NOT EXISTS columnValues (sno,roles,designation,team,status,workingStatus)');
                }).then(() => {
                  console.warn("Table created successfully");
                }).catch(error => {
                  console.warn("Hi" + error);
                });
                //Create Table For Employee Profile
                db.transaction((tx) => {
                  tx.executeSql('CREATE TABLE IF NOT EXISTS empProfile (empid, fullname, mobile, email, username, role, designation, team, empStatus)');
                }).then(() => {
                  console.log("Table created successfully");
                }).catch(error => {
                  console.log(error);
                });
                //Create Table For ManageEmployeeList
                db.transaction((tx) => {
                  tx.executeSql('CREATE TABLE IF NOT EXISTS manageEmployeesList (id,name,mobileNumber,' +
                    'email,userName,role,designation,team,empStatus,workingStatus)');
                }).then(() => {
                  console.log("Table created successfully");
                }).catch(error => {
                  console.log(error);
                });
                //Create Table For Pending Subtasks List
                db.transaction((tx) => {
                  tx.executeSql('CREATE TABLE IF NOT EXISTS pendingSubtasks (subTaskId,taskTitle,mainTaskTitle,' +
                    'mainTaskid,subTaskDesc,assignedBy,assignedDate,targetDate,taskEndDate,assignedTo,taskStatus,' +
                    'status,dependencyId,dependencyTitle,dependencyUser,modifiedDate,taskStatusDesc,activeStatus,' +
                    'timeLeft,today,count,cDate)');
                }).then(() => {
                  console.log("Table created successfully");
                }).catch(error => {
                  console.log(error);
                });
                //Create Table For Completed Subtasks List
                db.transaction((tx) => {
                  tx.executeSql('CREATE TABLE IF NOT EXISTS completedSubtasks (subTaskId,taskTitle,mainTaskTitle,' +
                    'subTaskDesc,assignedBy,assignedDate,targetDate,taskEndDate,assignedTo,taskStatus,' +
                    'status,dependencyId,dependencyTitle,dependencyUser,modifiedDate,taskStatusDesc,extraHours)');
                }).then(() => {
                  console.log("Table created successfully");
                }).catch(error => {
                  console.log(error);
                });
                //Create Table For Pending ManageTasks List
                db.transaction((tx) => {
                  tx.executeSql('CREATE TABLE IF NOT EXISTS manageTasksPending (projectitle,ideano,taskid,' +
                    'taskStatus,tasktitle,taskdescription,assignby,assigntto,taskStatusDesc,assignedon,' +
                    'taskEndDate,completeStatus,createdon,moduleId,targettime,assignedTo,cDate,' +
                    'timeLeft,ptime,count)');
                }).then(() => {
                  console.log("Table created successfully");
                }).catch(error => {
                  console.log(error);
                });
                //Create Table For Completed ManageTasks List
                db.transaction((tx) => {
                  tx.executeSql('CREATE TABLE IF NOT EXISTS manageTasksCompleted (projectitle,ideano,taskid,' +
                    'taskStatus,tasktitle,taskdescription,assignby,assigntto,taskStatusDesc,assignedon,' +
                    'taskEndDate,completeStatus,createdon,moduleId,targettime,assignedTo,cDate,' +
                    'extraHours,ptime)');
                }).then(() => {
                  console.log("Table created successfully");
                }).catch(error => {
                  console.log(error);
                });
                //Create Table For RequestedProjects List
                db.transaction((tx) => {
                  tx.executeSql('CREATE TABLE IF NOT EXISTS requestedProjectsList (idea_id,emp_id,idea_title,' +
                    'idea_description,created_on,userName)');
                }).then(() => {
                  console.log("Table created successfully");
                }).catch(error => {
                  console.log(error);
                });
                //Create Table For ApprovedProjects List
                db.transaction((tx) => {
                  tx.executeSql('CREATE TABLE IF NOT EXISTS approvedProjectsList (idea_id,emp_id,idea_title,' +
                    'releaseOwner,taskStatus,count,id,taskscount,acceptedDate,userName)');
                }).then(() => {
                  console.log("Table created successfully");
                }).catch(error => {
                  console.log(error);
                });
                //Create Table For ToBeCriticalRoadBlocks List
                db.transaction((tx) => {
                  tx.executeSql('CREATE TABLE IF NOT EXISTS toBeCriticalRoadBlocks (subTaskId,ideaTitle,status,' +
                    'taskTitle,taskDesc,targetDate,taskStatus,assignedDate,assignedby,taskStatusDesc,' +
                    'dependencyId,cDate)');
                }).then(() => {
                  console.log("Table created successfully");
                }).catch(error => {
                  console.log(error);
                });
                //Create Table For CriticalRoadBlocks List
                db.transaction((tx) => {
                  tx.executeSql('CREATE TABLE IF NOT EXISTS criticalRoadBlocks (subTaskId,ideaTitle,status,' +
                    'taskTitle,taskDesc,targetDate,taskStatus,assignedDate,assignedby,taskStatusDesc,' +
                    'dependencyId,cDate)');
                }).then(() => {
                  console.log("Table created successfully");
                }).catch(error => {
                  console.log(error);
                });
                //Create Table For Completed Projects List
                db.transaction((tx) => {
                  tx.executeSql('CREATE TABLE IF NOT EXISTS completedProjectsList (idea_id,emp_id,idea_title,' +
                      'releaseOwner,acceptedDate,userName)');
              }).then(() => {
                  console.log("Table created successfully");
              }).catch(error => {
                  console.log(error);
              });
              });
              resolve(db);
            })
            .catch(error => {
              console.warn(error);
            });
        })
        .catch(error => {
          console.warn("echoTest failed - plugin not functional"+error);
        });
    });
  };

  closeDatabase(db) {
    if (db) {
      console.log("Closing DB");
      db.close()
        .then(status => {
          console.log("Database CLOSED");
        })
        .catch(error => {
          this.errorCB(error);
        });
    } else {
      console.log("Database was not OPENED");
    }
  };

  listColumnValue() {
    console.warn("Query strated");
    return new Promise((resolve) => {
      const products = [];
      this.initDB().then((db) => {
        db.transaction((tx) => {
          tx.executeSql('SELECT * FROM columnValues', []).then(([tx, results]) => {
            console.warn("Query completed");
            var len = results.rows.length;
            for (let i = 0; i < len; i++) {
              let row = results.rows.item(i);
              console.warn("tesyt+" + row);
              console.log(`Prod ID: ${row.sno}, Prod Name: ${row.roles}`)
              const { sno, roles, designation, team, status, workingStatus } = row;
              products.push({
                sno, roles, designation, team, status, workingStatus
              });
            }
            console.warn("productDetails" + JSON.stringify(products))
            resolve(products);
          });

        }).then((result) => {
          this.closeDatabase(db);
        }).catch((err) => {
          console.log(err);
        });
      }).catch((err) => {
        console.log(err);
      });
    });
  }

  addColumnvalues(prod) {
    console.warn(prod.prodId)
    let array = [{
      "sno": "QPTMS",
      "roles": "QPTMS",
      "team": "android",
      "designation": "research",
      "status": "Available",
      "workingStatus": "Active"
    },
    {
      "sno": "CPTMS",
      "roles": "CPTMS",
      "team": "ReactNative",
      "designation": "research",
      "status": "Available",
      "workingStatus": "Active"
    }]
    console.warn(array)
    return new Promise((resolve) => {
      this.initDB().then((db) => {
        db.transaction((tx) => {
          array.forEach(element => {
            console.warn(element.roles)
            tx.executeSql('INSERT INTO columnValues VALUES (?, ?, ?, ?, ? ,?)', [element.sno, element.roles, element.designation, element.team, element.status, element.workingStatus]).then(([tx, results]) => {
              resolve(results);
            });
          });

        }).then((result) => {
          this.closeDatabase(db);
        }).catch((err) => {
          console.log(err);
        });
      }).catch((err) => {
        console.log(err);
      });
    });
  }

  updateProduct(id, prod) {
    return new Promise((resolve) => {
      this.initDB().then((db) => {
        db.transaction((tx) => {
          tx.executeSql('UPDATE Product SET prodName = ?, prodDesc = ?, prodImage = ?, prodPrice = ? WHERE prodId = ?', [prod.prodName, prod.prodDesc, prod.prodImage, prod.prodPrice, id]).then(([tx, results]) => {
            resolve(results);
          });
        }).then((result) => {
          this.closeDatabase(db);
        }).catch((err) => {
          console.log(err);
        });
      }).catch((err) => {
        console.log(err);
      });
    });
  }
  //Delete Profile Data
  deleteUser() {
    return new Promise((resolve) => {
      this.initDB().then((db) => {
        db.transaction((tx) => {
          tx.executeSql('DELETE FROM manageEmployeesList', []).then(([tx, results]) => {
            console.warn("deleted" + results);
            resolve(results);
          });
          tx.executeSql('DELETE FROM pendingSubtasks', []).then(([tx, results]) => {
            console.warn("deleted" + results);
            resolve(results);
          });
          tx.executeSql('DELETE FROM completedSubtasks', []).then(([tx, results]) => {
            console.warn("deleted" + results);
            resolve(results);
          });
          tx.executeSql('DELETE FROM empProfile', []).then(([tx, results]) => {
            console.warn("deleted" + results);
            resolve(results);
          });
          tx.executeSql('DELETE FROM manageTasksPending', []).then(([tx, results]) => {
            console.warn("deleted" + results);
            resolve(results);
          });
          tx.executeSql('DELETE FROM manageTasksCompleted', []).then(([tx, results]) => {
            console.warn("deleted" + results);
            resolve(results);
          });
          tx.executeSql('DELETE FROM requestedProjectsList', []).then(([tx, results]) => {
            console.warn("deleted" + results);
            resolve(results);
          });
          tx.executeSql('DELETE FROM approvedProjectsList', []).then(([tx, results]) => {
            console.warn("deleted" + results);
            resolve(results);
          });
          tx.executeSql('DELETE FROM criticalRoadBlocks', []).then(([tx, results]) => {
            console.warn("deleted" + results);
            resolve(results);
          });
          tx.executeSql('DELETE FROM toBeCriticalRoadBlocks', []).then(([tx, results]) => {
            console.warn("deleted" + results);
            resolve(results);
          });
          tx.executeSql('DELETE FROM completedProjectsList', []).then(([tx, results]) => {
            console.warn("deleted" + results);
            resolve(results);
        });
        }).then((result) => {
          this.closeDatabase(db);
        }).catch((err) => {
          console.warn("initdb" + JSON.stringify(err));
        });
      }).catch((err) => {
        console.warn("resolve" + err);
      });
    });
  }
}
