/**
 * FileName:UserDatabase.js
 * Purpose: For offline Store of Application in Very Screen from Side Navigation
 * Developers : NaveenKumar Gade (GNK)
 * Version : 1.0.0 on 14 May 2021
 */
import SQLite from "react-native-sqlite-storage";
SQLite.DEBUG(true);
SQLite.enablePromise(true);

const database_name = "Reactoffline.db";
const database_version = "1.0";
const database_displayname = "SQLite React Offline Database";
const database_size = 200000;

export default class UserDatabase {

    initDB() {
        let db;
        return new Promise((resolve) => {
            console.log("Plugin integrity check ...");
            SQLite.echoTest()
                .then(() => {
                    console.log("Integrity check passed ...");
                    console.log("Opening database ...");
                    SQLite.openDatabase(
                        database_name,
                        database_version,
                        database_displayname,
                        database_size
                    )
                        .then(DB => {
                            db = DB;
                            console.log("Database OPEN");
                            db.executeSql('SELECT 1 FROM userStories LIMIT 1').then(() => {
                                console.log("Database is ready ... executing query ...");
                            }).catch((error) => {
                                console.log("Received error: ", error);
                                console.log("Database not yet ready ... populating data");

                                // db.transaction((tx) => {
                                //   tx.executeSql('CREATE TABLE IF NOT EXISTS columnValues (sno,roles,designation,team,status,workingStatus)');
                                // }).then(() => {
                                //   console.warn("Table created successfully");
                                // }).catch(error => {
                                //   console.warn("Hi" + error);
                                // });
                                //Project List
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS agileProjects (key, label, color)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                                //Create Table For Employee Profile
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS empProfile (empid, fullname, mobile, email, username, role, shift_hours, free_licenses, empStatus,email_status,license_key,account_type,projectName)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                                //Create Table For ManageEmployeeList
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS manageEmployeesList (id,name,mobileNumber,' +
                                        'email,userName,role,designation,team,empStatus,workingStatus,projectName)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                                //Create Table For UserStories List
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS userStories (acceptanceCriteria,activeStatus,active_time,' +
                                        'assignedDate,assignedby,assignedbyid,assignedto,complete_status,created_date,estimated_hours,story_id,epic_id,' +
                                        'epic_name,modified_by,modified_date,sprint_desc,sprint_id,priority_level,storyPoints,subTaskDesc,' +
                                        'target_date,story_desc,task_end_date,taskStatus,story_status_desc,story_title,title,projectName,progress,blocked_id,project_id)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                                //Create Table For Completed Subtasks List
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS completedSubtasks (subTaskId,taskTitle,mainTaskTitle,' +
                                        'subTaskDesc,assignedBy,assignedDate,targetDate,taskEndDate,assignedTo,taskStatus,' +
                                        'status,dependencyId,dependencyTitle,dependencyUser,modifiedDate,taskStatusDesc,extraHours,projectName)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                                 //Create Table For Backlogs (Assigned (Sprints) and Unassigned)
                                 db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS backlogs (projectitle,moduletitle,id,' +
                                        'taskStatus,tasktitle,taskdescription,assignby,assigntto,taskStatusDesc,' +
                                        'assignedon,targettime,currenttime,taskEndDate,completeStatus,createdon,userstoryModuleId,ideano,storyPoints,acceptanceCriteria,'+
                                        'priorityLevel,assignedTo,modifiedDate,assignbyId,projectName,backlogStatus,userstory_id)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                                 //Sprint List
                                 db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS sprintsList (key,epicId,label,projectName)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                                //Archives List
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS archives (sprint_id,epic_id,sprint_desc,created_by,created_date,modified_by,modified_date,start_date,target_date,status,projectName,project_id,s_id)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                                //Create Table For Pending ManageTasks List
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS manageTasksPending (projectitle,ideano,taskid,' +
                                        'taskStatus,tasktitle,taskdescription,assignby,assigntto,taskStatusDesc,assignedon,' +
                                        'taskEndDate,completeStatus,createdon,moduleId,targettime,assignedTo,cDate,' +
                                        'timeLeft,ptime,count)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                                //Create Table For Completed ManageTasks List
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS manageTasksCompleted (projectitle,ideano,taskid,' +
                                        'taskStatus,tasktitle,taskdescription,assignby,assigntto,taskStatusDesc,assignedon,' +
                                        'taskEndDate,completeStatus,createdon,moduleId,targettime,assignedTo,cDate,' +
                                        'extraHours,ptime)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                                //Create Table For RequestedProjects List
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS requestedProjectsList (idea_id,emp_id,idea_title,' +
                                        'idea_description,created_on,userName)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                                //Create Table For ApprovedProjects List
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS approvedProjectsList (idea_id,e_id,idea_title,' +
                                        'releaseOwner,ideaStatus,count,id,taskscount,acceptedBy,acceptedDate,created_on,userName,projectName)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                                //Create Table For ToBeCriticalRoadBlocks List
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS blockedList (assignedby,assignedtoo,assigned_by,' +
                                        'assigned_date,assigned_to,assignedto,blocked_id,priority_level,project_id,r_id,requestedby,requested_by,' +
                                        'roadblock_date,roadblock_description,roadblock_status,severity_level,status,status_description,story_id,subtaskname,' +
                                        'target_date,task_end_date,roadblockStatus,projectName)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                                //Create Table For ToBeCriticalRoadBlocks List
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS toBeAssigned (assignedby,assigned_by,' +
                                        'assigned_date,assigned_to,assignedto,blocked_id,priority_level,project_id,r_id,requestedby,requested_by,' +
                                        'roadblock_date,roadblock_description,roadblock_status,severity_level,status,status_description,story_id,subtaskname,' +
                                        'target_date,task_end_date,roadblockStatus,projectName)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                                //Create Table For CriticalRoadBlocks List
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS criticalRoadBlocks (subTaskId,ideaTitle,status,' +
                                        'taskTitle,taskDesc,targetDate,taskStatus,assignedDate,assignedby,taskStatusDesc,' +
                                        'dependencyId,cDate)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                                //Create Table For Completed Projects List
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS completedProjectsList (idea_id,emp_id,idea_title,' +
                                        'releaseOwner,acceptedDate,userName)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                            });
                            resolve(db);
                        })
                        .catch(error => {
                            console.warn(error);
                        });
                })
                .catch(error => {
                    console.warn("echoTest failed - plugin not functional" + error);
                });
        });
    };

    closeDatabase(db) {
        if (db) {
            console.log("Closing DB");
            db.close()
                .then(status => {
                    console.log("Database CLOSED");
                })
                .catch(error => {
                    this.errorCB(error);
                });
        } else {
            console.log("Database was not OPENED");
        }
    };

    listColumnValue() {
        return new Promise((resolve) => {
            const products = [];
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('SELECT * FROM columnValues', []).then(([tx, results]) => {
                        
                        var len = results.rows.length;
                        for (let i = 0; i < len; i++) {
                            let row = results.rows.item(i);
                            // console.log(`Prod ID: ${row.sno}, Prod Name: ${row.roles}`)
                            const { sno, roles, designation, team, status, workingStatus } = row;
                            products.push({
                                sno, roles, designation, team, status, workingStatus
                            });
                        }
                        resolve(products);
                    });

                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }
    //Delete Profile Data
    deleteUser() {
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('DELETE FROM agileProjects', []).then(([tx, results]) => {
                        resolve(results);
                    });
                    tx.executeSql('DELETE FROM manageEmployeesList', []).then(([tx, results]) => {
                        resolve(results);
                    });
                    tx.executeSql('DELETE FROM userStories', []).then(([tx, results]) => {
                        resolve(results);
                    });
                    tx.executeSql('DELETE FROM backlogs', []).then(([tx, results]) => {
                        resolve(results);
                    });
                    tx.executeSql('DELETE FROM sprintsList', []).then(([tx, results]) => {
                        resolve(results);
                    });
                    tx.executeSql('DELETE FROM archives', []).then(([tx, results]) => {
                        resolve(results);
                    });
                    tx.executeSql('DELETE FROM completedSubtasks', []).then(([tx, results]) => {
                        resolve(results);
                    });
                    tx.executeSql('DELETE FROM empProfile', []).then(([tx, results]) => {
                        resolve(results);
                    });
                    tx.executeSql('DELETE FROM manageTasksPending', []).then(([tx, results]) => {
                        resolve(results);
                    });
                    tx.executeSql('DELETE FROM manageTasksCompleted', []).then(([tx, results]) => {
                        resolve(results);
                    });
                    tx.executeSql('DELETE FROM requestedProjectsList', []).then(([tx, results]) => {
                        resolve(results);
                    });
                    tx.executeSql('DELETE FROM approvedProjectsList', []).then(([tx, results]) => {
                        resolve(results);
                    });
                    tx.executeSql('DELETE FROM criticalRoadBlocks', []).then(([tx, results]) => {
                        resolve(results);
                    });
                    tx.executeSql('DELETE FROM blockedList', []).then(([tx, results]) => {
                        resolve(results);
                    });
                    tx.executeSql('DELETE FROM toBeAssigned', []).then(([tx, results]) => {
                        resolve(results);
                    });
                    tx.executeSql('DELETE FROM completedProjectsList', []).then(([tx, results]) => {
                        resolve(results);
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.warn("initdb" + JSON.stringify(err));
                });
            }).catch((err) => {
                console.warn("resolve" + err);
            });
        });
    }

    //Add profile Data of User
    addPendingSubtasks(userStories, projectName, progress) {
        let array = userStories
        this.deletePendingSubtasksListProject(projectName,progress)
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    array.forEach(stories => {
                        tx.executeSql('INSERT INTO userStories VALUES (?, ?, ?, ?, ?,?, ?, ?, ?, ?, ?, ?, ?, ?, ?,?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?,?,?)', [
                            stories.acceptanceCriteria, stories.activeStatus, stories.active_time,
                            stories.assignedDate, stories.assignedby, stories.assignedbyid, stories.assignedto, stories.complete_status,
                            stories.created_date, stories.estimated_hours, stories.story_id, stories.epic_id, stories.epic_name, stories.modified_by, stories.modified_date,
                            stories.sprint_desc, stories.sprint_id, stories.priority_level, stories.storyPoints, stories.subTaskDesc,
                            stories.target_date, stories.story_desc, stories.task_end_date, stories.taskStatus, stories.story_status_desc, stories.story_title, stories.title, projectName,progress,stories.blocked_id,stories.project_id
                        ]).then(([tx, results]) => {
                            resolve(results);
                        });
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.warn("err123" + JSON.stringify(err));
                });
            }).catch((err) => {
                console.warn("re" + err);
            });
        });
    }
    //Getting PendingSubtasksList Details 
    pendingSubtasksList(projectName, progress, moduleId) {
        return new Promise((resolve) => {
            const profile = [];
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('SELECT * FROM userStories WHERE projectName=? and progress=? and sprint_id=?', [projectName,progress,moduleId]).then(([tx, results]) => {
                        
                        var len = results.rows.length;
                        for (let i = 0; i < len; i++) {
                            let row = results.rows.item(i);
                            const { acceptanceCriteria, activeStatus, active_time,
                                assignedDate, assignedby, assignedbyid, assignedto, complete_status, created_date, estimated_hours, story_id, epic_id,
                                epic_name, modified_by, modified_date, sprint_desc, sprint_id, priority_level, storyPoints, subTaskDesc,
                                target_date, story_desc, task_end_date, taskStatus, story_status_desc, story_title, title, projectName,blocked_id,project_id } = row;
                            profile.push({
                                acceptanceCriteria, activeStatus, active_time,
                                assignedDate, assignedby, assignedbyid, assignedto, complete_status, created_date, estimated_hours, story_id, epic_id,
                                epic_name, modified_by, modified_date, sprint_desc, sprint_id, priority_level, storyPoints, subTaskDesc,
                                target_date, story_desc, task_end_date, taskStatus, story_status_desc, story_title, title, projectName,blocked_id,project_id
                            });
                        }
                        // console.warn(profile)
                        resolve(profile);
                    });

                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    deletePendingSubtasksListProject(projectName, progress) {
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('DELETE FROM userStories WHERE projectName=? and progress=?', [projectName,progress]).then(([tx, results]) => {
                        resolve(results);
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    //Store the Agile Projects List
    addAgileProjects(projects) {
        let array = projects
        this.deleteAgileProjects();
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    array.forEach(projects => {
                        tx.executeSql('INSERT INTO agileProjects VALUES (?, ?, ?)', [
                            projects.id, projects.value, projects.color
                        ]).then(([tx, results]) => {
                            resolve(results);
                        });
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.warn("err123" + JSON.stringify(err));
                });
            }).catch((err) => {
                console.warn("re" + err);
            });
        });
    }
    //Delete Agile Projects Whenever Logout the User
    deleteAgileProjects() {
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('DELETE FROM agileProjects', []).then(([tx, results]) => {
                        resolve(results);
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    //Getting Agile Projects List from offline Info  
    getAgileProjects() {
        return new Promise((resolve) => {
            const profile = [];
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('SELECT * FROM agileProjects ', []).then(([tx, results]) => {
                        var len = results.rows.length;
                        for (let i = 0; i < len; i++) {
                            let row = results.rows.item(i);
                            const { key, label, color } = row;
                            profile.push({ key, label, color });
                        }
                        resolve(profile);
                    });

                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    //Add ApprovedProjectsList Data
    addApprovedProjectsListOffline(approved, projectName,status) {
        let array = approved
        this.deleteApprovedProjectsListOffline(projectName,status);
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    array.forEach(approved => {
                        tx.executeSql('INSERT INTO approvedProjectsList VALUES (?, ?, ?, ?, ? ,?, ?, ? ,?, ?, ?, ?,?)', [
                            approved.idea_id, approved.e_id, approved.idea_title, approved.releaseOwner, approved.ideaStatus,
                            approved.count, approved.id, approved.taskscount,approved.acceptedBy, approved.acceptedDate,approved.created_on, approved.userName, projectName
                        ]).then(([tx, results]) => {
                            resolve(results);
                        });
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.warn("err" + JSON.stringify(err));
                });
            }).catch((err) => {
                console.warn("re" + err);
            });
        });
    }
    //Getting ApprovedProjectsList Details 
    getApprovedProjectsListOffline(projectName,status) {
        console.log("hello"+projectName)
        return new Promise((resolve) => {
            const profile = [];
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('SELECT * FROM approvedProjectsList WHERE projectName=? and ideaStatus=?', [projectName,status]).then(([tx, results]) => {
                        
                        var len = results.rows.length;
                        for (let i = 0; i < len; i++) {
                            let row = results.rows.item(i);
                            const { idea_id,e_id,idea_title,releaseOwner,ideaStatus,count,id,taskscount,acceptedBy,acceptedDate,created_on,userName,projectName } = row;
                            profile.push({
                                idea_id,e_id,idea_title,releaseOwner,ideaStatus,count,id,taskscount,acceptedBy,acceptedDate,created_on,userName,projectName
                            });
                        }
                        resolve(profile);
                    });

                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    //Delete ApprovedProjectsList
    deleteApprovedProjectsListOffline(projectName,status) {
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('DELETE FROM approvedProjectsList WHERE projectName=? and ideaStatus=?', [projectName,status]).then(([tx, results]) => {
                        resolve(results);
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    //Add ManageEmployees Data
    addManageEmployeesList(employee,projectName) {
        let array = employee
        this.deleteManageEmployeesList(projectName);
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    array.forEach(employee => {
                        console.warn(employee.subTaskId)
                    tx.executeSql('INSERT INTO manageEmployeesList VALUES (?, ?, ?, ?, ? ,?, ?, ? ,?, ?, ?)', [
                        employee.id,employee.name,employee.mobileNumber,employee.email,employee.userName,employee.role,
                        employee.designation,employee.team,employee.empStatus,employee.workingStatus,projectName
                    ]).then(([tx, results]) => {
                        resolve(results);
                    });
                });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.warn("err" + JSON.stringify(err));
                });
            }).catch((err) => {
                console.warn("re" + err);
            });
        });
    }
    //Getting ManageEmployees Details 
    getManageEmployeesList(projectName) {
        return new Promise((resolve) => {
            const profile = [];
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('SELECT * FROM manageEmployeesList WHERE projectName=?', [projectName]).then(([tx, results]) => {
                        var len = results.rows.length;
                        for (let i = 0; i < len; i++) {
                            let row = results.rows.item(i);
                            const { id,name,mobileNumber,email,userName,role,designation,team,empStatus,workingStatus,projectName } = row;
                            profile.push({
                                id,name,mobileNumber,email,userName,role,designation,team,empStatus,workingStatus,projectName
                            });
                        }
                        resolve(profile);
                    });

                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    //Delete ManageEmployeesList
    deleteManageEmployeesList(projectName) {
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('DELETE FROM manageEmployeesList WHERE projectName=?', [projectName]).then(([tx, results]) => {
                        resolve(results);
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    //Add Current Sprint and  Unassigned Backlogs
    addBacklogs(backlogs,backlogStatus,projectName,sprintId) {
        let array = backlogs
        this.deleteBacklogs(backlogStatus,projectName,sprintId);
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    array.forEach(backlogs => {
                    tx.executeSql('INSERT INTO backlogs VALUES (?, ?, ?, ?, ? ,?, ?, ? ,?, ?, ?, ?, ?, ?, ?, ? ,?, ?, ? ,?, ?, ? ,? ,?,?,?)', [
                        backlogs.projectitle,backlogs.moduletitle,backlogs.id,backlogs.taskStatus,backlogs.tasktitle,backlogs.taskdescription,
                        backlogs.assignby,backlogs.assigntto,backlogs.taskStatusDesc,backlogs.assignedon,backlogs.targettime,backlogs.currenttime,backlogs.taskEndDate,
                        backlogs.completeStatus,backlogs.createdon,backlogs.userstoryModuleId,backlogs.ideano,backlogs.storyPoints,backlogs.acceptanceCriteria,
                        backlogs.priorityLevel,backlogs.assignedTo,backlogs.modifiedDate,backlogs.assignbyId,projectName,backlogStatus,backlogs.userstory_id
                    ]).then(([tx, results]) => {
                        resolve(results);
                    });
                });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.warn("err" + JSON.stringify(err));
                });
            }).catch((err) => {
                console.warn("re" + err);
            });
        });
    }
    //Getting Unassigned Backlogs
    getBacklogs(backlogStatus,projectName) {
        return new Promise((resolve) => {
            const profile = [];
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('SELECT * FROM backlogs WHERE projectName=? and backlogStatus=?', [projectName,backlogStatus]).then(([tx, results]) => {
                        
                        var len = results.rows.length;
                        for (let i = 0; i < len; i++) {
                            let row = results.rows.item(i);
                            const { projectitle,moduletitle,id,taskStatus,tasktitle,taskdescription,assignby,assigntto,taskStatusDesc,
                                assignedon,targettime,currenttime,taskEndDate,completeStatus,createdon,userstoryModuleId,ideano,storyPoints,acceptanceCriteria,
                                priorityLevel,assignedTo,modifiedDate,assignbyId,projectName,backlogStatus,userstory_id } = row;
                            profile.push({
                                projectitle,moduletitle,id,taskStatus,tasktitle,taskdescription,assignby,assigntto,taskStatusDesc,
                                assignedon,targettime,currenttime,taskEndDate,completeStatus,createdon,userstoryModuleId,ideano,storyPoints,acceptanceCriteria,
                                priorityLevel,assignedTo,modifiedDate,assignbyId,projectName,backlogStatus,userstory_id
                            });
                        }
                        // console.warn(profile)
                        resolve(profile);
                    });

                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }
    //Getting Current or Feature Sprint Backlogs
    getAssignedBacklogs(backlogStatus,projectName,sprintId) {
        console.warn(sprintId)
        return new Promise((resolve) => {
            const profile = [];
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('SELECT * FROM backlogs WHERE projectName=? and backlogStatus=? and userstoryModuleId=?', [projectName,backlogStatus,sprintId]).then(([tx, results]) => {
                        
                        var len = results.rows.length;
                        for (let i = 0; i < len; i++) {
                            let row = results.rows.item(i);
                            const { projectitle,moduletitle,id,taskStatus,tasktitle,taskdescription,assignby,assigntto,taskStatusDesc,
                                assignedon,targettime,currenttime,taskEndDate,completeStatus,createdon,userstoryModuleId,ideano,storyPoints,acceptanceCriteria,
                                priorityLevel,assignedTo,modifiedDate,assignbyId,projectName,backlogStatus,userstory_id } = row;
                            profile.push({
                                projectitle,moduletitle,id,taskStatus,tasktitle,taskdescription,assignby,assigntto,taskStatusDesc,
                                assignedon,targettime,currenttime,taskEndDate,completeStatus,createdon,userstoryModuleId,ideano,storyPoints,acceptanceCriteria,
                                priorityLevel,assignedTo,modifiedDate,assignbyId,projectName,backlogStatus,userstory_id
                            });
                        }
                        // console.warn(profile)
                        resolve(profile);
                    });

                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    //Delete Current Sprint and  Unassigned Backlogs based on backlogStatus and projectName
    deleteBacklogs(backlogStatus,projectName,sprintId) {
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    if(sprintId === '0'){
                        tx.executeSql('DELETE FROM backlogs WHERE projectName=? and backlogStatus=?', [projectName,backlogStatus]).then(([tx, results]) => {
                            resolve(results);
                        });
                    }else{
                    tx.executeSql('DELETE FROM backlogs WHERE projectName=? and backlogStatus=? and userstoryModuleId=?', [projectName,backlogStatus,sprintId]).then(([tx, results]) => {
                        resolve(results);
                    });
                    }
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    //Store the Agile Projects List
    addSprints(sprints,projectName) {
        let array = sprints
        this.deleteSprints(projectName);
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    array.forEach(sprints => {
                        tx.executeSql('INSERT INTO sprintsList VALUES (?, ?, ?, ?)', [
                            sprints.key, sprints.epicId, sprints.label,projectName
                        ]).then(([tx, results]) => {
                            resolve(results);
                        });
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.warn("err123" + JSON.stringify(err));
                });
            }).catch((err) => {
                console.warn("re" + err);
            });
        });
    }
    //Delete Agile Projects Whenever Logout the User
    deleteSprints(projectName) {
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('DELETE FROM sprintsList where projectName=?', [projectName]).then(([tx, results]) => {
                        resolve(results);
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    //Getting Agile Projects List from offline Info  
    getSprints(projectName) {
        return new Promise((resolve) => {
            const profile = [];
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('SELECT * FROM sprintsList where projectName=? ', [projectName]).then(([tx, results]) => {
                        var len = results.rows.length;
                        for (let i = 0; i < len; i++) {
                            let row = results.rows.item(i);
                            const { key,epicId, label,projectName } = row;
                            profile.push({ key, epicId, label, projectName });
                        }
                        resolve(profile);
                        // alert(JSON.stringify(profile) +"profile")
                    });

                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }
    //Getting Agile Projects List from offline Info  
    getActiveSprint(projectName) {
        return new Promise((resolve) => {
            const profile = [];
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('SELECT * FROM sprintsList where projectName=? LIMIT 1', [projectName]).then(([tx, results]) => {
                        var len = results.rows.length;
                        for (let i = 0; i < len; i++) {
                            let row = results.rows.item(i);
                            const { key,epicId, label,projectName } = row;
                            profile.push({ key, epicId, label, projectName });
                        }
                        resolve(profile);
                    });

                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }
   //Add Archive Lists of User
    addArchivesList(sprints, projectName) {
        let array = sprints
        this.deleteArchivesList(projectName)
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    array.forEach(sprints => {
                        tx.executeSql('INSERT INTO archives VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)', [
                            sprints.sprint_id,sprints.epic_id,sprints.sprint_desc,sprints.created_by,sprints.created_date,sprints.modified_by,
                            sprints.modified_date,sprints.start_date,sprints.target_date,sprints.status,projectName,sprints.project_id,sprints.s_id
                        ]).then(([tx, results]) => {
                            resolve(results);
                        });
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.warn("err123" + JSON.stringify(err));
                });
            }).catch((err) => {
                console.warn("re" + err);
            });
        });
    }
    //Getting PendingSubtasksList Details 
    getArchiveList(projectName) {
        return new Promise((resolve) => {
            const profile = [];
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('SELECT * FROM archives WHERE projectName=?', [projectName]).then(([tx, results]) => {
                        
                        var len = results.rows.length;
                        for (let i = 0; i < len; i++) {
                            let row = results.rows.item(i);
                            const { sprint_id,epic_id,sprint_desc,created_by,created_date,modified_by,modified_date,start_date,target_date,status,projectName,project_id,s_id} = row;
                            profile.push({
                                sprint_id,epic_id,sprint_desc,created_by,created_date,modified_by,modified_date,start_date,target_date,status,projectName,project_id,s_id
                            });
                        }
                        // console.warn(profile)
                        resolve(profile);
                    });

                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    deleteArchivesList(projectName) {
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('DELETE FROM archives WHERE projectName=?', [projectName]).then(([tx, results]) => {
                        resolve(results);
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    } 
      //Add profile Data of User
      addProfile(profile,projectName) {
        console.warn(profile)
        let array = profile;
        this.deleteProfile(projectName);
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    array.forEach(profile => {
                        tx.executeSql('INSERT INTO empProfile VALUES (?, ?, ?, ?, ? ,?, ?, ? ,? ,? ,?, ?, ?)',[profile.empid, profile.fullname, profile.mobile, profile.email, profile.username,profile.role, profile.shift_hours, profile.free_licenses, profile.empStatus,profile.email_status,profile.license_key,profile.account_type,projectName]).then(([tx, results]) => {
                                resolve(results);
                                console.warn("success")
                            });
                        });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.warn("err"+JSON.stringify(err));
                });
            }).catch((err) => {
                console.warn("re"+err);
            });
        });
    }
    //Getting Profile Details 
    profileList(projectName) {
        console.warn("Query strated");
        return new Promise((resolve) => {
            const profile=[];
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('SELECT * FROM empProfile where projectName=?', [projectName]).then(([tx, results]) => {
                        console.warn("Query completed");
                        var len = results.rows.length;
                        for (let i = 0; i < len; i++) {
                            let row = results.rows.item(i);
                            const { empid, fullname, mobile, email, username, role, shift_hours, free_licenses, empStatus,email_status,license_key,account_type,projectName } = row;
                            profile.push({
                                empid, fullname, mobile, email, username, role,shift_hours, free_licenses, empStatus,email_status,license_key,account_type,projectName
                            });
                        }
                        console.warn(profile)
                        resolve(profile);
                    });

                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    //Delete Profile Data
    deleteProfile(projectName) {
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('DELETE FROM empProfile where projectName=?', [projectName]).then(([tx, results]) => {
                        console.warn("deleted"+results);
                        resolve(results);
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    //Store the roadblocks List
addRoadblocks(blockedList,projectName,roadblockStatus) {
    let array = blockedList
    this.deleteRoadblocks(projectName,roadblockStatus);
    return new Promise((resolve) => {
        this.initDB().then((db) => {
            db.transaction((tx) => {
                array.forEach(blocks => {
                    tx.executeSql('INSERT INTO blockedList VALUES (?, ?, ?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)', [
                        blocks.assignedby,blocks.assignedtoo,blocks.assigned_by,blocks.assigned_date,blocks.assigned_to,
                        blocks.assignedto,blocks.blocked_id,blocks.priority_level,blocks.project_id,blocks.r_id,blocks.requestedby,blocks.requested_by,
                        blocks.roadblock_date,blocks.roadblock_description,blocks.roadblock_status,blocks.severity_level,blocks.status,
                        blocks.status_description,blocks.story_id,blocks.subtaskname,blocks.target_date,blocks.task_end_date,roadblockStatus,projectName
                    ]).then(([tx, results]) => {
                        resolve(results);
                    });
                });
            }).then((result) => {
                this.closeDatabase(db);
            }).catch((err) => {
                console.warn("err123" + JSON.stringify(err));
            });
        }).catch((err) => {
            console.warn("re" + err);
        });
    });
}
//Delete roadblocks
deleteRoadblocks(projectName,roadblockStatus) {
    return new Promise((resolve) => {
        this.initDB().then((db) => {
            db.transaction((tx) => {
                tx.executeSql('DELETE FROM blockedList where roadblockStatus=? and projectName=?', [roadblockStatus,projectName]).then(([tx, results]) => {
                    resolve(results);
                });
            }).then((result) => {
                this.closeDatabase(db);
            }).catch((err) => {
                console.log(err);
            });
        }).catch((err) => {
            console.log(err);
        });
    });
}

//Getting roadblocks List from offline Info  
getRoadblocks(roadblockStatus,projectName) {
    return new Promise((resolve) => {
        const profile = [];
        this.initDB().then((db) => {
            db.transaction((tx) => {
                tx.executeSql('SELECT * FROM blockedList  where roadblockStatus=? and projectName=?', [roadblockStatus,projectName]).then(([tx, results]) => {
                    var len = results.rows.length;
                    for (let i = 0; i < len; i++) {
                        let row = results.rows.item(i);
                        const { assignedby,assignedtoo,assigned_by,assigned_date,assigned_to,assignedto,blocked_id,
                            priority_level,project_id,r_id,requestedby,requested_by,roadblock_date,roadblock_description,
                            roadblock_status,severity_level,status,status_description,story_id,subtaskname,
                            target_date,task_end_date,roadblockStatus,projectName } = row;
                        profile.push({assignedby,assignedtoo,assigned_by,assigned_date,assigned_to,assignedto,blocked_id,
                            priority_level,project_id,r_id,requestedby,requested_by,roadblock_date,roadblock_description,
                            roadblock_status,severity_level,status,status_description,story_id,subtaskname,
                            target_date,task_end_date,roadblockStatus,projectName });
                    }
                    resolve(profile);
                });

            }).then((result) => {
                this.closeDatabase(db);
            }).catch((err) => {
                console.log(err);
            });
        }).catch((err) => {
            console.log(err);
        });
    });
}

    //Store the roadblocks List
    addToBeAssignedRoadblocks(blockedList,projectName,roadblockStatus) {
        let array = blockedList
        this.deleteToBeAssignedRoadblocks(projectName,roadblockStatus);
        return new Promise((resolve) => {
            this.initDB().then((db) => { 
                db.transaction((tx) => {
                    array.forEach(blocks => {
                        tx.executeSql('INSERT INTO toBeAssigned VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)', [
                            blocks.assignedby,blocks.assigned_by,blocks.assigned_date,blocks.assigned_to,
                            blocks.assignedto,blocks.blocked_id,blocks.priority_level,blocks.project_id,blocks.r_id,blocks.requestedby,blocks.requested_by,
                            blocks.roadblock_date,blocks.roadblock_description,blocks.roadblock_status,blocks.severity_level,blocks.status,
                            blocks.status_description,blocks.story_id,blocks.subtaskname,blocks.target_date,blocks.task_end_date,roadblockStatus,projectName
                        ]).then(([tx, results]) => {
                            resolve(results);
                        });
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.warn("err123" + JSON.stringify(err));
                });
            }).catch((err) => {
                console.warn("re" + err);
            });
        });
    }
    //Delete roadblocks
    deleteToBeAssignedRoadblocks(projectName,roadblockStatus) {
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('DELETE FROM toBeAssigned where roadblockStatus=? and projectName=?', [roadblockStatus,projectName]).then(([tx, results]) => {
                        resolve(results);
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }
    
    //Getting roadblocks List from offline Info  
    getToBeAssignedRoadblocks(roadblockStatus,projectName) {
        return new Promise((resolve) => {
            const profile = [];
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('SELECT * FROM toBeAssigned  where roadblockStatus=? and projectName=?', [roadblockStatus,projectName]).then(([tx, results]) => {
                        var len = results.rows.length;
                        for (let i = 0; i < len; i++) {
                            let row = results.rows.item(i);
                            const { assignedby,assigned_by,assigned_date,assigned_to,assignedto,blocked_id,priority_level,project_id,r_id,
                                requestedby,requested_by,roadblock_date,roadblock_description,roadblock_status,severity_level,status,
                                status_description,story_id,subtaskname,target_date,task_end_date,roadblockStatus,projectName } = row;
                            profile.push({assignedby,assigned_by,assigned_date,assigned_to,assignedto,blocked_id,priority_level,project_id,r_id,
                                requestedby,requested_by,roadblock_date,roadblock_description,roadblock_status,severity_level,status,
                                status_description,story_id,subtaskname,target_date,task_end_date,roadblockStatus,projectName });
                        }
                        resolve(profile);
                    });
    
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

}