/*
FileName:UserBacklogActive.js
Version:1.0.0
Purpose:List of Backlogs of Active sprint of assigned user stories
Devloper:Mahesh, Naveen Kumar(GNK)->Offline
*/
import React, { Component } from 'react';
import { Platform, StyleSheet, Image, Text, View, Dimensions, TouchableOpacity, FlatList, LayoutAnimation, UIManager, TextInput, Alert, ToastAndroid } from 'react-native';
import { Container, Content, Item, Input, Header, Icon } from 'native-base';
import { widthPercentageToDP as wp, heightPercentageToDP as hp } from 'react-native-responsive-screen';
// import Icon from 'react-native-vector-icons/FontAwesome';
import { Collapse, CollapseHeader, CollapseBody } from "accordion-collapse-react-native";
// import DropDownPicker from 'react-native-dropdown-picker';
import ModalSelector from 'react-native-modal-selector';
import Modal from "react-native-simple-modal";
import jwt_decode from "jwt-decode";
import AsyncStorage from '@react-native-community/async-storage';
import { API } from "../WebServices/RestClient";
import NetInfo from '@react-native-community/netinfo';
import Snackbar from 'react-native-snackbar';
import Toast from 'react-native-whc-toast';
import log from '../LogFile/Log';
import DatePicker from 'react-native-datepicker';
import { NavigationEvents } from 'react-navigation';
import { MYTASK, PENDING, COMPLETED, BLOCKED, ADDMODULE, MODULE_TITLE, MODULEINFO } from '../CommonComponents/Header'
import moment from 'moment';

import {
  BallIndicator,
  BarIndicator,
  DotIndicator,
  MaterialIndicator,
  PacmanIndicator,
  PulseIndicator,
  SkypeIndicator,
  UIActivityIndicator
} from 'react-native-indicators';
import { SUBTASK, TITLE, DESCRIPTION, ADDMAINTASK, TARGETTIME, TASKSTATUS, ASSIGNEDON, STATUS, ASSIGNED_BY, UPDATEDON, TIMELEFT, MODIFY, UPDATESTATUS, TARGET_DATE, ASSIGNED_TO } from '../CommonComponents/Header';
import UserDatabase from '../OfflineDB/UserDatabase';
const db = new UserDatabase();

FOOTER_MAX_HEIGHT = 50
FOOTER_MIN_HEIGHT = 40

class ListItem extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      isLoading: true,
      expanded: false,
      date: '1:00',
      dataSource2: [],
    }

    this.getMessages();
    if (Platform.OS === 'android') {
      UIManager.setLayoutAnimationEnabledExperimental(true);
    }

  }
  changeLayout = () => {
    LayoutAnimation.configureNext(LayoutAnimation.Presets.easeInEaseOut);
    this.setState({ expanded: !this.state.expanded });
  }


  getMessages() {
    log("Info", " getMessages(role, userToken, cropcode) is used getting task related messages");
    // const groupId = this.state.subtaskId;
    // console.warn("getmessages");
    AsyncStorage.multiGet(["cropcode", "userToken"], (err, response) => {
      const cropcode = response[0][1];
      const userToken = response[1][1];
      this.setState({ userid: userToken });
      // console.warn("userToken"+userToken)
      // console.warn("cropcode"+cropcode)

      NetInfo.fetch().then(state => {
        if (state.type == "none") {
          log("Warn", "No internet connection");
          Snackbar.show({
            title: 'No Internet Connection',
            backgroundColor: 'red',
            duration: Snackbar.LENGTH_LONG,
          });
        }
        else {
          fetch(API + "mainTaskChat.php",
            {
              method: 'POST',
              headers: {
                Accept: 'application/json',
                'Content-Type': 'application/json',
              },
              body: JSON.stringify({

                action: "getAllTaskMessages",
                corp_code: cropcode,
                // sendBy: userToken,


              })
            })
            .then((response) => response.json())
            .then((responseJson) => {
              // console.warn("Messages For chat application" + JSON.stringify(responseJson.data));

              // console.warn("Messages from users" + JSON.stringify(responseJson))
              // console.warn("Send By Name" + JSON.stringify(responseJson.data))
              if (responseJson.status === 'True') {

                // console.warn("Setted Data")



                this.setState({
                  dataSource2: responseJson.data,
                });
                // console.warn("Method data" + responseJson.data.sendBy)
              }
              else {
                // console.warn("Empty  Data")
                this.setState({
                  dataSource2: [],
                });
              }
            })
            .catch((error) => {
              console.error(error);
              log("Error", "getting task related messages error");
            });

        }
      });
    });
  }


  //Navigates to TaskChat Screen
  TaskChat(taskid, action, msgCount) {
    // console.warn("msgCount" + msgCount);
    // console.warn("taskid" + taskid);
    log("Info", "UserPendingMyTasks:TaskChat(item, index) used to navigate to taskchat")
    this.props.navigation.navigate("TaskChat", { id: taskid, action: "maintask", sno: msgCount });
  }

  render() {
    const { item } = this.props;

    let button;
    if (item.completeStatus === "pending") {

      button =
        <View style={{ flexDirection: 'row', justifyContent: 'flex-end', alignItems: 'center' }}>

          <TouchableOpacity style={{ padding: 5, backgroundColor: '#76C54E', marginLeft: 8, borderRadius: 10 }} onPress={() => this.props.ModifyStory()}>
            <Text style={{ color: 'white', fontSize: 10 }}>MODIFY</Text>
          </TouchableOpacity>
          <TouchableOpacity style={{ padding: 5, backgroundColor: '#3DD896', marginLeft: 8, borderRadius: 10 }} onPress={() => this.props.AddSprint()}>
            <Text style={{ color: 'white', fontSize: 10 }}>Add to Sprint</Text>
          </TouchableOpacity>
          <TouchableOpacity style={{ padding: 5, backgroundColor: '#F4A896', marginLeft: 8, borderRadius: 10 }} onPress={() => this.props.AddEpic()}>
            <Text style={{ color: 'white', fontSize: 10 }}>Add to Epic</Text>
          </TouchableOpacity>


        </View>



    } else {

      button = null;

    }

    let buttonD;
    if (item.activeStatus !== "-1" && item.completeStatus === 'pending' && item.backlogs === '1') {

      buttonD =
        <View style={{ flexDirection: 'row', alignItems: 'center', marginTop: 5 }}>
          {/* <TouchableOpacity style={{ padding: 5, backgroundColor: '#630436', marginLeft: 8, borderRadius: 10 }} onPress={() => this.props.TaskAdd()}>
            <Text style={{ color: 'white', fontSize: 10 }}>Add Task</Text>
          </TouchableOpacity> */}
          <TouchableOpacity style={{ padding: 5, backgroundColor: '#855723', marginLeft: 2, borderRadius: 10 }} onPress={() => this.props.ChangeStatus()}>
            <Text style={{ color: 'white', fontSize: 10 }}>Change Status</Text>
          </TouchableOpacity>
          {/* <TouchableOpacity style={{ padding: 5, backgroundColor: '#203B5A', marginLeft: 8, borderRadius: 10 }} onPress={() => this.props.ViewTask()}>
            <Text style={{ color: 'white', fontSize: 10 }}>View Tasks</Text>
          </TouchableOpacity> */}


        </View>



    } else {

      buttonD = null;

    }
    let buttonD1;
    if (item.activeStatus === "0" && item.completeStatus === 'pending') {

      buttonD1 =
        <View style={{ flexDirection: 'row', alignItems: 'center', marginTop: 5 }}>
          {/* <TouchableOpacity style={{ padding: 5, backgroundColor: '#630436', marginLeft: 8, borderRadius: 10 }} onPress={() => this.props.TaskAdd()}>
            <Text style={{ color: 'white', fontSize: 10 }}>Add Task</Text>
          </TouchableOpacity> */}
          <TouchableOpacity style={{ padding: 5, backgroundColor: '#855723', marginLeft: 2, borderRadius: 10 }} onPress={() => this.props.ChangeStatus1()}>
            <Text style={{ color: 'white', fontSize: 10 }}>Change Status InProgress</Text>
          </TouchableOpacity>
          {/* <TouchableOpacity style={{ padding: 5, backgroundColor: '#203B5A', marginLeft: 8, borderRadius: 10 }} onPress={() => this.props.ViewTask()}>
            <Text style={{ color: 'white', fontSize: 10 }}>View Tasks</Text>
          </TouchableOpacity> */}


        </View>



    } else {

      buttonD1 = null;

    }


    let buttonA;
    if (item.completeStatus === 'pending') {

      buttonA =
        <View style={{ flexDirection: 'row', alignItems: 'center', marginTop: 5 }}>
          <TouchableOpacity style={{ padding: 5, backgroundColor: '#630436', marginLeft: 2, borderRadius: 10 }} onPress={() => this.props.TaskAdd()}>
            <Text style={{ color: 'white', fontSize: 10 }}>Add Task</Text>
          </TouchableOpacity>

          <TouchableOpacity style={{ padding: 5, backgroundColor: '#203B5A', marginLeft: 2, borderRadius: 10 }} onPress={() => this.props.ViewTask()}>
            <Text style={{ color: 'white', fontSize: 10 }}>View Tasks</Text>
          </TouchableOpacity>


        </View>



    } else {

      buttonA = null;

    }
    let button1;
    if (item.completeStatus === "completed") {

      button1 =
        <View style={{ flexDirection: 'row', justifyContent: 'flex-end', alignItems: 'center' }}>

          <TouchableOpacity style={{ padding: 5, backgroundColor: 'orange', marginLeft: 10, borderRadius: 10 }} onPress={() => this.props.ReassignStory()}>
            <Text style={{ color: 'white', fontSize: 10 }}>Reassign</Text>
          </TouchableOpacity>
        </View>



    } else {

      button1 = null;

    }


    //  // var data1=this.state.dataSource1;
    //  const getMessagesCount = (data, msg, task, empId) => {
    //   //  console.warn("ids"+JSON.stringify(data1) +id)

    //   //  var msg=this.state.dataSource1;
    //   // console.warn("Datasource and id send by"+JSON.stringify(data1.sendBy))
    //   // let msgCount = data1.filter(message => message.sendBy === id).map((messages, i) => {
    //     let msgCount = msg.filter(message => message.readBy.split(",").indexOf(empId) === -1 && message.messagedBy !== empId && message.groupId === task.taskid).map((messages, i) => {

    //     return i

    //   })

    //   // console.warn("iiiiiiii" + msgCount)

    //   return (
    //     // console.warn("iiiiiiii" + msgCount),
    //     <View>
    //       <Text style={{ color: 'green' }}> {msgCount.length > 0 ? msgCount.length : null} </Text>
    //       {/* {msgCount.length > 0 ? msgCount.length : null} */}
    //       {
    //         msgCount.length > 0 ?

    //           <Icon name="comments" style={{ color: '#808080', paddingRight: 5 }} size={25} onPress={() => { this.props.TaskChat() }} />

    //           :
    //           <Icon name="comments" style={{ color: '#808080', paddingRight: 5 }} size={25} onPress={() => { this.props.TaskChat() }} />


    //       }

    //     </View>
    //   )

    // }


    // var data1=this.state.dataSource1;
    const getMessagesCount = (id, msg, empId) => {
      //  console.warn("ids"+JSON.stringify(data1) +id)

      //  var msg=this.state.dataSource1;
      // console.warn("Datasource and id send by"+JSON.stringify(data1.sendBy))
      // let msgCount = data1.filter(message => message.sendBy === id).map((messages, i) => {
      let msgCount = msg.filter(message => message.readBy.split(",").indexOf(empId) === -1 && message.messagedBy !== empId && message.groupId === id).map((messages, i) => {

        return i, messages

      })

      // console.warn("iiiiiiii" + id)
      // console.warn("msgcount" + msgCount)

      return (
        // console.warn("iiiiiiii" + msgCount),
        <View>
          <Text style={{ color: 'green', paddingTop: -20, marginRight: 10 }}> {msgCount.length > 0 ? msgCount.length : null} </Text>
          {/* {msgCount.length > 0 ? msgCount.length : null} */}
          {
            msgCount.length > 0 ?

              <TouchableOpacity style={{ marginTop: -20, marginLeft: 10 }} onPress={() => { this.TaskChat(id, "maintask", msgCount) }}>
                <Image style={{ width: 25, height: 25 }} source={require('../Images/chat.png')} />
              </TouchableOpacity>
              :
              <TouchableOpacity style={{ marginTop: -20, marginLeft: 10 }} onPress={() => { this.TaskChat(id, "maintask", msgCount) }}>
                <Image style={{ width: 25, height: 25, }} source={require('../Images/chat.png')} />

              </TouchableOpacity>

          }

        </View>
      )

    }




    return (

      <View>

        {/* <Collapse style={[item.cDate >= item.targetDate ? styles.container : styles.container1]}>

          <CollapseHeader style={styles.boxheader}> */}
        {/* <View style={[item.targettime <= item.cDate ? styles.container : styles.container1]}> */}
        <View style={[(item.currenttime > item.targettime && item.completeStatus === 'pending' && item.targettime !== '0000-00-00') ? styles.c : styles.c1]}>

          <View style={styles.boxheader}>
            <TouchableOpacity activeOpacity={0.8} onPress={this.changeLayout} >
              {/* <CollapseHeader style={[item.timeLeft<0?styles.boxheader:styles.boxheader1]} > */}


              <View style={{ flexDirection: 'row' }}>
                <View style={{ flexDirection: 'row', width: wp('25%') }}>
                  {/* <Text style={styles.signUpText0} >Id:</Text> */}
                  <Text style={styles.signUpText0} >{(this.props.cropcode).substring(0, 3).toUpperCase()}:</Text>

                  <Text style={styles.signUpText1} > {item.userstory_id.substring(0, 5).toUpperCase()} {item.moduleId}</Text>
                </View>
                <View style={{ alignItems: 'flex-end', width: '70%' }}>
                  <Text >{item.assigntto}</Text>
                </View>
                {/* <Text style={styles.signUpText02} >{item.completeStatus}  </Text> */}
                <View>


                </View>

              </View>


              <View style={styles.box1}>
                <View style={{ flexDirection: 'row', width: wp('86%') }}>
                {item.completeStatus === 'pending' ?
                  <Text style={styles.signUpText00} >User Story Name:</Text>
                  :<Text style={styles.signUpText00m} >User Story Name:</Text>
        }
                  {item.completeStatus === 'pending' ?
                    <Text style={{ fontSize: 13, color: '#000000', width: '55%',paddingLeft: 10, }} >{item.tasktitle}</Text>
                    : <Text style={{ fontSize: 13, color: '#000000', width: '55%', textDecorationLine: 'line-through',paddingLeft: 10, }} >{item.tasktitle}</Text>
                  }

                </View>
                {getMessagesCount(item.id, this.state.dataSource2, this.props.empId)}

              </View>



            </TouchableOpacity>
          </View>
          {/* </CollapseHeader> */}
          <View style={{ height: this.state.expanded ? null : 0, overflow: 'hidden' }}>

            <CollapseBody>

              <View style={styles.box12}>
                {button}
                {button1}
                <View style={{ backgroundColor: '#6DAE8C', marginLeft: 10, width: 25, height: 25, textAlign: 'center', justifyContent: 'center' }}>
                  <Text style={{ color: 'white', paddingLeft: 8, fontSize: 10 }}>{item.storyPoints}</Text>
                </View>
                <View style={{ backgroundColor: 'teal', marginLeft: 10, width: 35, height: 25, textAlign: 'center', justifyContent: 'center' }}>
                  <Text style={{ color: 'white', paddingLeft: 8, fontSize: 10 }}>P:{item.priorityLevel}</Text>
                </View>

              </View>
              <View  style={styles.box12}>
                {buttonA}

                {buttonD}
                {buttonD1}
              </View>

              <View style={{ flexDirection: 'row', paddingRight: 25, width: wp('85%') }}>
                <Text style={styles.signUpText44} >Description:</Text>
                <Text style={styles.signUpText33} >{item.taskdescription}</Text>
              </View>
              <View style={{ flexDirection: 'row', paddingRight: 25, width: wp('68%') }}>
                <Text style={styles.signUpText44} >Acceptance Criteria : </Text>
                <Text style={styles.signUpText33} >{item.acceptanceCriteria}</Text>
              </View>
              <View style={styles.box1}>
                <View style={{ flexDirection: 'row', width: wp('80%') }}>
                  <Text style={styles.signUpText000} >Assigned On:</Text>
                  <Text style={styles.signUpText111} >{moment(item.assignedon).format('MM.DD.YYYY')}</Text>
                </View>
                {/* <Text style={styles.signUpText002} >{TASKSTATUS}:{item.taskStatus}%Completed</Text> */}
              </View>
              <View style={{ flexDirection: 'row', paddingRight: 25, width: wp('80%') }}>
                <Text style={styles.signUpText44} >Story Progress:</Text>
                <Text style={styles.signUpText33} >{item.taskStatus}%Completed</Text>
              </View>

              <View style={{ flexDirection: 'row', paddingRight: 25, width: wp('80%') }}>
                <Text style={styles.signUpText44} >{ASSIGNED_BY} :</Text>
                <Text style={styles.signUpText33} >{item.assignby}</Text>
              </View>




            </CollapseBody>
          </View>
        </View>
        {/* </Collapse> */}
        {/* <View style={{ backgroundColor: '#C0C0C0', height: 2 }}> */}
        {/* </View> */}
      </View>
    )
  }
}

export default class UserBacklogActive extends Component {
  static navigationOptions = () => {
    return {
      tabBarOnPress({ navigation, defaultHandler }) {
        navigation.state.params.onTabFocus();
        defaultHandler();
        this.onRefresh();
      }
    };
  }

  constructor(props) {
    super(props);
    props.navigation.setParams({
      onTabFocus: this.handleTabFocus
    });
    this.state = {
      isLoading: true,
      dataSource: [],
      isFetching: false,
      open: false,
      ProjectTitle: "",
      ProjectDescription: "",
      role: '',
      userToken: '',
      getInvolved: [],
      unassignedTasks: [],
      currentsprint: [],
      manageTasks: [],
      resource: [],
      pendingTasks: [],
      backlogs: [],
      error1: '', error2: '',
      itemPressedDisabled: false,
      date: '12:00'
    };
    this.unassignedTasksData();

    AsyncStorage.getItem("cropcode", (err, res) => {
      this.setState({ squadName: res });
      // console.warn("squadname" + this.state.squadName);
    });
    this.arrayholder = [];

  }
  handleTabFocus = () => {
    this.onRefresh();
  };


  //Dialog Actions start
  moveUp = () => this.setState({ offset: -100 });

  resetPosition = () => this.setState({ offset: 0 });

  openModal = () => this.setState({ open: true });

  //close dialog
  closeModal = () => {
    this.setState({
      open: false, error1: '', startDate: '', targetDate: ''
    });
    this.setState({ modulename: '' })
  }
  componentDidMount() {
    AsyncStorage.getItem("cropcode", (err, res) => {
      this.setState({ cropcode: res });
      console.warn(this.state.cropcode);
    });
    AsyncStorage.getItem("emp_role", (err, res) => {
      this.setState({ emp_role: res });

      console.warn(this.state.emp_role)
    });
    log("Debug", "admin request projects screen is loaded");
    // this.ideas();
    this.getRequestedIdeas();
    this.GetStatus();
    // this.getModules();
    this.getActiveSprints();//active sprint user stories
    // this.getSprints();
    // this.getUnactiveSprintTasks();
    this.getUnassigned();//Backlogs user stories
    this.getModules();
    this.getSprints1();
    this.getUnactiveSprintTasks();
    this.getPending();
    this.unassignedTasksData();

    AsyncStorage.getItem("userToken", (err, res) => {
      this.setState({ empId: res });

      // console.warn(this.state.empId);
    });

  }


  //For store Agile projects for offline Start
  addAgileProjects(data) {
    // console.warn("hello naveen" + JSON.stringify(data));
    db.addAgileProjects(data).then((result) => {
      console.log(result);
    }).catch((err) => {
      console.log(err);
    })
  }
  //For store Agile projects for offline End
  //For Getting offline Project List Start
  getAgileProjects() {
    db.getAgileProjects().then((data) => {
      // console.warn("AgileProjectsList" + JSON.stringify(data))
      this.setState({
        data2: data,
      });
    }).catch((err) => {
    })
  }
  //For Getting offline Project List End

  //For store Sprints or offline Start
  addOfflineSprints(sprints, projectName) {
    db.addSprints(sprints, projectName).then((result) => {
      console.log(result);
    }).catch((err) => {
      console.log(err);
    })
  }
  //For store Sprints for offline End
  //For Getting offline Sprints List Start
  getOfflineSprints() {
    AsyncStorage.getItem("cropcode", (err, res) => {
      const projectName = res;
      db.getSprints(projectName).then((data) => {
        console.warn("SprintsList" + JSON.stringify(data))
        this.setState({
          resource: data,
        });
      }).catch((err) => {
      })
    });
  }
  //For Getting offline Sprints List End
  //For Getting offline Active Sprints List Start
  getOfflineActiveSprints(backlogsStatus) {
    AsyncStorage.getItem("cropcode", (err, res) => {
      const projectName = res;
      db.getActiveSprint(projectName).then((data) => {
        console.warn("Active Sprint" + JSON.stringify(data[0].key))
        this.setState({
          moduleId: data[0].key,
          moduleDesc: data[0].label
        })
        this.getAssignedBacklogs(backlogsStatus, data[0].key)
      }).catch((err) => {
        this.setState({
          currentsprint: [],
          moduleId: '0',
          moduleDesc: '',
          isLoading: false,
        });
      })
    });
  }
  //For Getting offline Active Sprints List End
  //For Getting Current or Feature Sprint Backlogs from offline
  getAssignedBacklogs(backlogsStatus, sprintId) {
    AsyncStorage.getItem("cropcode", (err, res) => {
      const projectName = res;
      db.getAssignedBacklogs(backlogsStatus, projectName, sprintId).then((data) => {
        console.warn(data)
        this.setState({
          currentsprint: data,
          isLoading: false,
        });
        this.arrayholder = data;
      }).catch((err) => {
        console.log(err);
        this.setState = {
          isLoading: false
        }
      })
    })
  }
  //For Getting Current or Feature Sprint Backlogs from offline

  //For Getting Current Sprint and  Unassigned Backlogs from offline
  getBacklogs(backlogsStatus) {
    AsyncStorage.getItem("cropcode", (err, res) => {
      const projectName = res;
      db.getBacklogs(backlogsStatus, projectName).then((data) => {
        if (backlogsStatus === "currentsprint") {
          this.setState({
            currentsprint: data,
            isLoading: false,
          });
        } else {
          this.setState({
            unassignedTasks: data,
            isLoading: false,
          });
        }
        this.arrayholder = data;
      }).catch((err) => {
        console.log(err);
        this.setState = {
          isLoading: false
        }
      })
    })
  }
  //For Getting Current Sprint and  Unassigned Backlogs from offline

  //For store Current Sprint and  Unassigned Backlogs from offline
  addBacklogs(backlogs, backlogStatus, projectName, sprintId) {
    // console.warn("hello" + JSON.stringify(backlogs));
    db.addBacklogs(backlogs, backlogStatus, projectName, sprintId).then((result) => {
      this.setState({
        isLoading: false,
      });
    }).catch((err) => {
      console.log(err);
      this.setState({
        isLoading: false,
      });
    })
  }

  componentWillReceiveProps(nextProps) {
    NetInfo.fetch().then(state => {
      if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
        console.log(state.type);
        Snackbar.show({
          title: 'No Internet Connection',
          backgroundColor: 'red',
          duration: Snackbar.LENGTH_LONG,
        });
        // this.getPendingtasksList(); //For pending subtaskslist from offline
      } else {
        //to get the user pending my task list
        // this.getActiveSprints();
        // this.getUnassigned();
        this.ideas();
        this.getRequestedIdeas();
        this.GetStatus();
        this.getModules();
        this.getActiveSprints();
        this.getSprints1();
        this.getUnactiveSprintTasks();
        this.getUnassigned();
        this.getPending();
        this.unassignedTasksData();
      }
    });

  }

  //get modules data
  getModules() {
    log("Info", "UserProfile:GetStatus() method is used to get status of employee");
    AsyncStorage.getItem("empId", (err, res) => {
      const empId = res;
      AsyncStorage.getItem("cropcode", (err, res) => {
        const cropcode = res;
        AsyncStorage.getItem("emp_role", (err, res) => {
          const emp_role = res;
          NetInfo.fetch().then(state => {
            if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
              // console.log(state.type);
              Snackbar.show({
                title: 'No Internet Connection',
                backgroundColor: 'red',
                duration: Snackbar.LENGTH_LONG,
              });
            } else {

              fetch(API + 'getModules.php', {
                method: 'POST',
                headers: {
                  Accept: 'application/json',
                  'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                  crop: cropcode,
                  userType: emp_role,
                  empId: empId,

                  action: "getModules",


                })
              })
                .then((response) => response.json())
                .then((responseJson) => {
                  // alert("getmodules data" + JSON.stringify(responseJson.data))
                  // console.warn("getmodules data" + JSON.stringify(responseJson.data));
                  if (responseJson.status == 'True') {
                    this.setState({
                      isLoading: false,
                      dataSource1: [...responseJson.data],
                    }, function () {
                      // In this block you can do something with new state.
                    });

                  } else {
                    log("Warn", "status of employee is not available");
                  }
                })
                .catch((error) => {
                  console.error(error);
                  log("Error", "error in  getting status of employee");
                });
            }
          });
        });
      });
    });

  }


  //get ActiveSprints data
  getActiveSprints() {
    log("Info", "UserProfile:GetStatus() method is used to get status of employee");
    AsyncStorage.getItem("empId", (err, res) => {
      const empId = res;
      AsyncStorage.getItem("cropcode", (err, res) => {
        const cropcode = res;
        AsyncStorage.getItem("emp_role", (err, res) => {
          const emp_role = res;
          AsyncStorage.getItem("projectId", (err, res) => {
            const projectId = res;
            NetInfo.fetch().then(state => {
              if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
                // console.log(state.type);
                Snackbar.show({
                  title: 'No Internet Connection',
                  backgroundColor: 'red',
                  duration: Snackbar.LENGTH_LONG,
                });
                this.getOfflineActiveSprints("currentsprint")//Getting Current Sprint Backlogs in offline
                this.getBacklogs("currentsprint") //Getting Current Sprint Backlogs in offline
              } else {

                fetch(API + 'getUpdateSprint.php', {
                  method: 'POST',
                  headers: {
                    Accept: 'application/json',
                    'Content-Type': 'application/json',
                  },
                  body: JSON.stringify({
                    crop: cropcode,
                    userType: emp_role,
                    empId: empId,

                    action: "get_sprints",
                    projectId: projectId


                  })
                })
                  .then((response) => response.json())
                  .then((responseJson) => {
                    //alert(JSON.stringify(responseJson.data))
                    // console.warn("getActiveSprint data" + JSON.stringify(responseJson.data));
                    if (responseJson.status == 'True') {
                      this.setState({
                        isLoading: false,
                        dataSource1: [...responseJson.data],
                        moduleId: responseJson.data[0].moduleId,
                        ideaId: responseJson.data[0].ideaId,
                        moduleDesc: responseJson.data[0].moduleDesc,
                        startDate: responseJson.data[0].startDate,
                        targetDate: responseJson.data[0].targetDate,
                        sprint_status: responseJson.data[0].sprint_status,

                      }, function () {
                        // In this block you can do something with new state.
                      });
                      AsyncStorage.setItem('moduleId', responseJson.data[0].moduleId);
                      AsyncStorage.setItem('ideaId', responseJson.data[0].ideaId);

                      this.getInvolvedEmployees(responseJson.data[0].moduleId)
                      this.getRequestedIdeas(responseJson.data[0].moduleId)

                    } else {
                      //For No Active Sprints
                      this.setState({
                        isLoading: false,
                        dataSource1: [],
                        moduleId: '',
                        moduleDesc: ''
                      })
                      log("Warn", "status of employee is not available");
                    }
                  })
                  .catch((error) => {
                    console.error(error);
                    log("Error", "error in  getting status of employee");
                  });
              }
            });
          });
        });
      });
    });

  }


  //get getInvolvedEmployees data
  getInvolvedEmployees(moduleId) {
    log("Info", "UserProfile:GetStatus() method is used to get status of employee");
    AsyncStorage.getItem("empId", (err, res) => {
      const empId = res;
      AsyncStorage.getItem("cropcode", (err, res) => {
        const cropcode = res;
        AsyncStorage.getItem("emp_role", (err, res) => {
          const emp_role = res;
          AsyncStorage.getItem("projectId", (err, res) => {
            const projectId = res;
            NetInfo.fetch().then(state => {
              if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
                // console.log(state.type);
                Snackbar.show({
                  title: 'No Internet Connection',
                  backgroundColor: 'red',
                  duration: Snackbar.LENGTH_LONG,
                });
              } else {

                fetch(API + 'get_sprints.php', {
                  method: 'POST',
                  headers: {
                    Accept: 'application/json',
                    'Content-Type': 'application/json',
                  },
                  body: JSON.stringify({
                    crop: cropcode,
                    moduleId: moduleId,
                    // userType: emp_role,
                    // empId: empId,

                    action: "get_involved_employees",
                    projectId: projectId


                  })
                })
                  .then((response) => response.json())
                  .then((responseJson) => {
                    console.warn("getActiveSprint data" + JSON.stringify(responseJson.data));
                    if (responseJson.status == 'True') {
                      this.setState({
                        isLoading: false,
                        getInvolved: [...responseJson.data],
                      }, function () {
                        // In this block you can do something with new state.
                      });

                    } else {
                      log("Warn", "status of employee is not available");
                    }
                  })
                  .catch((error) => {
                    console.error(error);
                    log("Error", "error in  getting status of employee");
                  });
              }
            });
          });
        });
      });
    });

  }

  //Validatios
  isValid() {
    // alert("Test"+this.state.license_key)
    const { moduleDesc } = this.state;
    let valid = false;

    if (moduleDesc.length === 0) {
      log("Warn", "Enter Module Description");
      // this.setState({ error1: 'Enter licenses_key' });
      alert("Enter Module Description")
    }



    else {
      valid = true;
    }
    return valid;
  }


  //update the new Module
  modifyModule() {

    const { moduleDesc, startDate, targetDate } = this.state;
    const { moduleId } = this.state;
    // console.log("moduleId" + idea_id);
    console.log("modulename" + moduleDesc);
    console.warn("startDate" + startDate);
    console.warn("targetDate" + targetDate);

    //getting cropcode,usertoken(emp id)
    AsyncStorage.multiGet(["cropcode", "userToken"], (err, response) => {
      const cropcode = response[0][1];
      const userToken = response[1][1];
      console.log("userToken" + userToken);
      console.log("cropcode" + cropcode);
      AsyncStorage.getItem("projectId", (err, res) => {
        const projectId = res;
        NetInfo.fetch().then(state => {
          if (state.type == "none") {
            console.log(state.type);
            log("Warn", "No internet connection");
            Snackbar.show({
              title: 'No Internet Connection',
              backgroundColor: 'red',
              duration: Snackbar.LENGTH_LONG,
            });
          }
          else {

            if (this.isValid()) {
              this.setState({ itemPressedDisabled: true })
              fetch(API + 'manage_sprints.php',
                {
                  method: 'POST',
                  headers: {
                    Accept: 'application/json',
                    'Content-Type': 'application/json',
                  },
                  body: JSON.stringify({
                    action: 'modify',
                    crop: cropcode,
                    module_Name: moduleDesc,
                    moduleId: moduleId,
                    startDate: startDate,
                    targetDate: targetDate,
                    empId: userToken,
                    projectId: projectId

                  })
                })
                .then((response) => response.json())
                .then((responseJson) => {
                  console.warn("Sprint Added" + JSON.stringify(responseJson))
                  // this.refs.toast.show('Sprint Added', Toast.Duration.long, Toast.Position.center);
                  if (responseJson.status == 'True') {
                    this.setState({ itemPressedDisabled: false })
                    this.setState({ open: false, error1: '', startDate: '', targetDate: '', });
                    alert("Sprint Modified")
                    // this.getModules();
                    this.getSprints();
                    // this.getActive();
                    this.UpdateSprint();
                    this.getActiveSprints();
                  }

                })
                .catch((error) => {
                  console.error(error);
                  log("Error", "error in project modifying");
                });
              this.closeModal();
            }
          }
        });
      });
    });

  }

  // delete Employee start
  deleteAction() {
    // alert("moduleId" + sprintId)
    // alert("ideaId"+ideaId)
    // alert(email+""+empid)
    log("Info", "UserManageProjects1:deleteAction(moduleId) method is used to give alert");
    Alert.alert(
      'Alert..!',
      'Do you want to delete Sprint',
      [
        {
          text: 'Cancel',
          onPress: () => console.log('Cancel Pressed'),
          style: 'cancel',
        },
        { text: 'OK', onPress: () => this.deleteSprint() },
      ],
      { cancelable: false },
    );
  }

  deleteSprint() {

    const { moduleId } = this.state;
    // alert(moduleId)
    //getting cropcode,usertoken(emp id)
    AsyncStorage.multiGet(["cropcode", "userToken"], (err, response) => {
      const cropcode = response[0][1];
      const userToken = response[1][1];
      console.log("userToken" + userToken);
      console.log("cropcode" + cropcode);
      AsyncStorage.getItem("projectId", (err, res) => {
        const projectId = res;
        const data = {
          moduleId: moduleId,
          action: 'delete',
          crop: cropcode,
          empId: userToken
        };
        NetInfo.fetch().then(state => {
          if (state.type == "none") {
            console.log(state.type);
            log("Warn", "No internet connection");
            Snackbar.show({
              title: 'No Internet Connection',
              backgroundColor: 'red',
              duration: Snackbar.LENGTH_LONG,
            });
          }
          else {


            fetch(API + 'manage_sprints.php',
              {
                method: 'POST',
                headers: {
                  Accept: 'application/json',
                  'Content-Type': 'application/json',
                },
                body: JSON.stringify(
                  data

                )
              })
              .then((response) => response.json())
              .then((responseJson) => {
                alert(JSON.stringify(responseJson));
                // this.refs.toast.show('Sprint Added', Toast.Duration.long, Toast.Position.center);
                if (responseJson.status == 'True') {
                  this.setState({ itemPressedDisabled: false })
                  alert(responseJson.message);
                  // alert("Sprint Modified")
                  // this.getModules();
                  // this.getSprints();
                  // this.getActive();
                  //   this.UpdateSprint();
                  this.getActiveSprints();
                }
                else {
                  alert(responseJson.message);
                }

              })
              .catch((error) => {
                console.error(error);
                log("Error", "error in project modifying");
              });
            this.closeModal();
          }

        });
      });
    });

  }

  // deleteSprint() {
  //   // const { moduleId} = this.state;
  //   //  alert("moduleid" + moduleId + "mod")
  //   //  alert(this.state.ideaId);
  //   log("Info", "deleteProject() method is used to delete project");
  //   AsyncStorage.multiGet(["cropcode", "userToken", "emp_role"], (err, response) => {
  //     const cropcode = response[0][1];
  //     const userToken = response[1][1];
  //     // alert(userToken)
  //     console.warn("userToken" + userToken)
  //     const role = response[2][1];
  //     AsyncStorage.getItem("projectId", (err, res) => {
  //       const projectId = res;
  //       AsyncStorage.getItem("moduleId", (err, res) => {
  //         const moduleId = res;
  //       // alert(moduleId)
  //       const data = {
  //         moduleId: moduleId,
  //         action: "delete",
  //         crop: cropcode,
  //         empId: userToken
  //       };

  //       // alert("delete"+JSON.stringify(data))
  //       NetInfo.fetch().then(state => {
  //         if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
  //           console.log(state.type);
  //           Snackbar.show({
  //             title: 'No Internet Connection',
  //             backgroundColor: 'red',
  //             duration: Snackbar.LENGTH_LONG,
  //           });
  //         } else {
  //           // console.warn(item)
  //           // alert(this.state.email)
  //           fetch(API + 'manage_sprints.php', {
  //             method: 'POST',
  //             headers: {
  //               'Accept': 'application/json',
  //               'Content-Type': 'application/json',
  //             },
  //             body: JSON.stringify({
  //               data,

  //             })
  //           }).then((response) => response.json())
  //             .then((responseJson) => {
  //               console.log(JSON.stringify(responseJson));
  //               // console.log(responseJson);
  //               // alert(JSON.stringify(responseJson));
  //               if (responseJson.status === 'True') {
  //                 // this.refs.toast.showCenter('Epic Squad is Deactivated', Toast.Duration.long, Toast.Position.center);
  //                 console.log("done")
  //                 // this.deactiveEmployee(email);
  //                 alert(responseJson.message);
  //                 // alert("Employee is Deleted");
  //                 //this.refs.toast.showBottom('Employee is Deleted');

  //                 this.setState({ open: false })
  //                 // this.props.navigation.navigate('Aproved');
  //                 // this.UserManageEmployees();
  //               }
  //               else {
  //                 // alert(responseJson.message);
  //                 // this.refs.toast.showCenter('Epic Squad is not Deactivated', Toast.Duration.long, Toast.Position.center);
  //               }
  //             }).catch((error) => {
  //               console.error(error);
  //               //alert("Hello");
  //               log("Error", "error in employee deletion");
  //             });
  //         }
  //       });
  //     });
  //     });
  //   });
  // };



  // delete Employee start
  ArchiveAction(moduleId) {
    // alert("moduleId" + moduleId)
    // alert("ideaId"+ideaId)
    // alert(email+""+empid)
    log("Info", "UserManageProjects1:ArchiveAction(moduleId) method is used to give alert");
    Alert.alert(
      'Alert..!',
      'Do you want to move into Archive',
      [
        {
          text: 'Cancel',
          onPress: () => console.log('Cancel Pressed'),
          style: 'cancel',
        },
        { text: 'OK', onPress: () => this.deleteArchive(moduleId) },
      ],
      { cancelable: false },
    );
  }

  deleteArchive(moduleId) {
    // alert(moduleId)
    // const { moduleId ,ideaId} = this.state;
    //  alert(this.state.ideaId);

    log("Info", "deleteProject() method is used to delete project");
    AsyncStorage.multiGet(["cropcode", "userToken", "emp_role"], (err, response) => {
      const cropcode = response[0][1];
      const userToken = response[1][1];
      console.warn("userToken" + userToken)
      const role = response[2][1];
      AsyncStorage.getItem("projectId", (err, res) => {
        const projectId = res;
        const data = {
          empId: userToken,
          crop: cropcode,
          action: "move_to_archive",
          // idea_id: ideaId,
          moduleId: moduleId,
        };
        // alert(JSON.stringify(data))
        NetInfo.fetch().then(state => {
          if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
            console.log(state.type);
            Snackbar.show({
              title: 'No Internet Connection',
              backgroundColor: 'red',
              duration: Snackbar.LENGTH_LONG,
            });
          } else {
            // console.warn(item)
            // alert(this.state.email)
            fetch(API + 'manage_sprints.php', {
              method: 'POST',
              headers: {
                'Accept': 'application/json',
                'Content-Type': 'application/json',
              },
              body: JSON.stringify(
                data



              )
            }).then((response) => response.json())
              .then((responseJson) => {
                console.log(JSON.stringify(responseJson));
                // console.log(responseJson);
                // alert(JSON.stringify(responseJson));
                if (responseJson.status === 'True') {
                  // this.refs.toast.showCenter('Epic Squad is Deactivated', Toast.Duration.long, Toast.Position.center);
                  console.log("done")
                  // this.deactiveEmployee(email);
                  alert(responseJson.message);
                  alert("Employee is Deleted");
                  //this.refs.toast.showBottom('Employee is Deleted');

                  this.setState({ open: false })
                  // this.props.navigation.navigate('Aproved');
                  // this.UserManageEmployees();
                }
                else {
                  alert(responseJson.message);
                  // this.refs.toast.showCenter('Epic Squad is not Deactivated', Toast.Duration.long, Toast.Position.center);
                }
              }).catch((error) => {
                console.error(error);
                //alert("Hello");
                log("Error", "error in employee deletion");
              });
          }
        });
      });
    });
  };

  // delete Employee start
  SprintAction(moduleId, action) {
    // alert("moduleId" + moduleId)
    // alert(action)
    // alert("ideaId"+ideaId)
    // alert(email+""+empid)
    log("Info", "UserBacklogActive:SprintAction(moduleId) method is used to give alert");
    Alert.alert(
      'Alert..!',
      'Do you want to Commit',
      [
        {
          text: 'Cancel',
          onPress: () => console.log('Cancel Pressed'),
          style: 'cancel',
        },
        { text: 'OK', onPress: () => this.deleteCommit(moduleId, action) },
      ],
      { cancelable: false },
    );
  }
  SprintAction1(moduleId, action) {
    // alert("moduleId" + moduleId)
    // alert("ideaId"+ideaId)
    // alert(email+""+empid)
    log("Info", "UserBacklogActive:SprintAction(moduleId) method is used to give alert");
    Alert.alert(
      'Alert..!',
      'Do you want to Uncommit',
      [
        {
          text: 'Cancel',
          onPress: () => console.log('Cancel Pressed'),
          style: 'cancel',
        },
        { text: 'OK', onPress: () => this.deleteCommit(moduleId, action) },
      ],
      { cancelable: false },
    );
  }
  deleteCommit(moduleId, action) {
    // alert(moduleId)
    // const { moduleId ,ideaId} = this.state;
    //  alert(this.state.ideaId);
    log("Info", "deleteProject() method is used to delete project");
    AsyncStorage.multiGet(["cropcode", "userToken", "emp_role"], (err, response) => {
      const cropcode = response[0][1];
      const userToken = response[1][1];
      console.warn("userToken" + userToken)
      const role = response[2][1];
      AsyncStorage.getItem("projectId", (err, res) => {
        const projectId = res;
        const data = {
          empId: userToken,
          crop: cropcode,
          action: 'commit_sprint',
          // idea_id: ideaId,
          moduleId: moduleId,
          sprint_status: (action === 'uncommit_sprint') ? "pending" : "commited"
        }
        NetInfo.fetch().then(state => {
          if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
            console.log(state.type);
            Snackbar.show({
              title: 'No Internet Connection',
              backgroundColor: 'red',
              duration: Snackbar.LENGTH_LONG,
            });
          } else {
            // console.warn(item)
            // alert(this.state.email)
            fetch(API + 'manage_sprints.php', {
              method: 'POST',
              headers: {
                'Accept': 'application/json',
                'Content-Type': 'application/json',
              },
              body: JSON.stringify(
                data,


              )
            }).then((response) => response.json())
              .then((responseJson) => {
                console.log(JSON.stringify(responseJson));
                // console.log(responseJson);
                alert(JSON.stringify(responseJson));
                if (responseJson.status === 'True') {
                  // this.refs.toast.showCenter('Epic Squad is Deactivated', Toast.Duration.long, Toast.Position.center);
                  console.log("done")
                  // this.deactiveEmployee(email);
                  alert(responseJson.message);
                  // alert("Employee is Deleted");
                  //this.refs.toast.showBottom('Employee is Deleted');

                  this.setState({ open: false })
                  // this.props.navigation.navigate('Aproved');
                  // this.UserManageEmployees();
                }
                else {
                  alert(responseJson.message);
                  // this.refs.toast.showCenter('Epic Squad is not Deactivated', Toast.Duration.long, Toast.Position.center);
                }
              }).catch((error) => {
                console.error(error);
                //alert("Hello");
                log("Error", "error in employee deletion");
              });
          }
        });
      });
    });
  };

  //get Sprints data
  getSprints() {
    log("Info", "UserProfile:GetStatus() method is used to get status of employee");
    AsyncStorage.getItem("userToken", (err, res) => {
      const empId = res;
      AsyncStorage.getItem("cropcode", (err, res) => {
        const cropcode = res;
        AsyncStorage.getItem("emp_role", (err, res) => {
          const emp_role = res;
          NetInfo.fetch().then(state => {
            if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
              // console.log(state.type);
              Snackbar.show({
                title: 'No Internet Connection',
                backgroundColor: 'red',
                duration: Snackbar.LENGTH_LONG,
              });
            } else {

              fetch(API + 'getModules.php', {
                method: 'POST',
                headers: {
                  Accept: 'application/json',
                  'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                  crop: cropcode,
                  userType: emp_role,
                  empId: empId,

                  action: "getModules",


                })
              })
                .then((response) => response.json())
                .then((responseJson) => {
                  // console.warn("get Sprints data" + JSON.stringify(responseJson.data));
                  if (responseJson.status == 'True') {
                    this.setState({
                      isLoading: false,
                      dataSource1: [...responseJson.data],
                    }, function () {
                      // In this block you can do something with new state.
                    });

                  } else {
                    log("Warn", "status of employee is not available");
                  }
                })
                .catch((error) => {
                  console.error(error);
                  log("Error", "error in  getting status of employee");
                });
            }
          });
        });
      });
    });

  }

  //get pending data
  getPending() {
    log("Info", "UserProfile:GetStatus() method is used to get status of employee");
    AsyncStorage.getItem("empId", (err, res) => {
      const empId = res;
      AsyncStorage.getItem("cropcode", (err, res) => {
        const cropcode = res;
        AsyncStorage.getItem("emp_role", (err, res) => {
          const emp_role = res;
          NetInfo.fetch().then(state => {
            if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
              // console.log(state.type);
              Snackbar.show({
                title: 'No Internet Connection',
                backgroundColor: 'red',
                duration: Snackbar.LENGTH_LONG,
              });
            } else {

              fetch(API + 'backlogspage.php', {
                method: 'POST',
                headers: {
                  Accept: 'application/json',
                  'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                  crop: cropcode,
                  userType: emp_role,
                  empId: empId,

                  action: "pending",


                })
              })
                .then((response) => response.json())
                .then((responseJson) => {
                  // alert(JSON.stringify(responseJson.data))
                  if (responseJson.status == 'true') {

                    console.warn("Pending Tasks" + JSON.stringify(responseJson.data));
                    this.setState({
                      isLoading: false,
                      pendingTasks: [...responseJson.data],
                    }, function () {
                      // In this block you can do something with new state.
                    });
                    this.arrayholder = responseJson.data;

                  } else {
                    this.arrayholder = [];
                    log("Warn", "status of employee is not available");
                    this.setState({
                      isLoading: false,
                      pendingTasks: []
                    })
                  }
                })
                .catch((error) => {
                  console.error(error);
                  log("Error", "error in  getting status of employee");
                });
            }
          });
        });
      });
    });

  }


  //get UnactiveSprintTasks data
  getUnactiveSprintTasks() {
    log("Info", "UserProfile:GetStatus() method is used to get status of employee");
    AsyncStorage.getItem("empId", (err, res) => {
      const empId = res;
      AsyncStorage.getItem("cropcode", (err, res) => {
        const cropcode = res;
        AsyncStorage.getItem("emp_role", (err, res) => {
          const emp_role = res;
          NetInfo.fetch().then(state => {
            if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
              // console.log(state.type);
              Snackbar.show({
                title: 'No Internet Connection',
                backgroundColor: 'red',
                duration: Snackbar.LENGTH_LONG,
              });
            } else {

              fetch(API + 'backlogspage.php', {
                method: 'POST',
                headers: {
                  Accept: 'application/json',
                  'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                  crop: cropcode,
                  userType: emp_role,
                  empId: empId,

                  action: "getUnactiveSprintTasks",


                })
              })
                .then((response) => response.json())
                .then((responseJson) => {
                  // console.warn("getUnactiveSprintTasks data" + JSON.stringify(responseJson.data));
                  if (responseJson.status == 'True') {
                    this.setState({
                      isLoading: false,
                      dataSource1: [...responseJson.data],
                    }, function () {
                      // In this block you can do something with new state.
                    });

                  } else {
                    log("Warn", "status of employee is not available");
                  }
                })
                .catch((error) => {
                  console.error(error);
                  log("Error", "error in  getting status of employee");
                });
            }
          });
        });
      });
    });

  }


  //get Unassigned data
  getUnassigned() {
    log("Info", "UserProfile:GetStatus() method is used to get status of employee");
    AsyncStorage.getItem("empId", (err, res) => {
      const empId = res;
      AsyncStorage.getItem("cropcode", (err, res) => {
        const cropcode = res;
        AsyncStorage.getItem("emp_role", (err, res) => {
          const emp_role = res;
          NetInfo.fetch().then(state => {
            if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
              // console.log(state.type);
              Snackbar.show({
                title: 'No Internet Connection',
                backgroundColor: 'red',
                duration: Snackbar.LENGTH_LONG,
              });
              this.getBacklogs("unassigned") //For Getting Unassigned Backlogs in offline 
            } else {

              fetch(API + 'backlogspage.php', {
                method: 'POST',
                headers: {
                  Accept: 'application/json',
                  'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                  crop: cropcode,
                  //   userType: emp_role,
                  //   empId: empId,

                  //     action: "getUnactiveSprintTasks",


                })
              })
                .then((response) => response.json())
                .then((responseJson) => {
                  // alert("Unassigned Tasks" + JSON.stringify(responseJson.data))
                  if (responseJson.status == 'true') {

                    console.warn("Unassigned Tasks" + JSON.stringify(responseJson.data));
                    this.addBacklogs(responseJson.data, "unassigned", cropcode, '0')//For offline store of Unassigned Backlogs
                    this.setState({
                      isLoading: false,
                      unassignedTasks: [...responseJson.data],
                    }, function () {
                      // In this block you can do something with new state.
                    });
                    this.arrayholder = responseJson.data;

                  } else {
                    this.arrayholder = [];
                    log("Warn", "status of employee is not available");
                    this.setState({
                      isLoading: false,
                      unassignedTasks: []
                    })
                  }
                })
                .catch((error) => {
                  console.error(error);
                  log("Error", "error in  getting status of employee");
                });
            }
          });
        });
      });
    });

  }



  //get project list dropdown data
  GetStatus() {
    log("Info", "UserProfile:GetStatus() method is used to get status of employee");
    AsyncStorage.getItem("userName", (err, res) => {
      const userName = res;
      NetInfo.fetch().then(state => {
        if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
          // console.log(state.type);
          Snackbar.show({
            title: 'No Internet Connection',
            backgroundColor: 'red',
            duration: Snackbar.LENGTH_LONG,
          });
          this.getAgileProjects()//For Getting Project List in Offline
        } else {

          fetch(API + 'squadsList.php', {
            method: 'POST',
            headers: {
              Accept: 'application/json',
              'Content-Type': 'application/json',
            },
            body: JSON.stringify({

              username: userName,


            })
          })
            .then((response) => response.json())
            .then((responseJson) => {
              // console.warn(responseJson)
              if (responseJson.status == 'True') {
                // this.setState({
                //     isLoading: false,
                //     dataSource1: [...responseJson.data],
                // }, function () {
                //     // In this block you can do something with new state.
                // });
                this.addAgileProjects(responseJson.data) //Project list store in offline
                console.log("Testing" + JSON.stringify(responseJson.data))
                const data2 = [];

                responseJson.data.map(x => {
                  data2.push({ label: x.value, value: x.value })
                })
                this.setState({
                  data2: data2,
                })
                // console.warn("Hello" + JSON.stringify(data2))

                // this.setState({
                //     data2: responseJson.data
                // });
                // console.warn(this.state.data2);
              } else {
                log("Warn", "status of employee is not available");
              }
            })
            .catch((error) => {
              console.error(error);
              log("Error", "error in  getting status of employee");
            });
        }
      });
    });

  }

  // Update Status of Employee
  UpdateStatus(squadName) {
    // const { squadName } = this.state;
    log("Info", "UserProfile:UpdateStatus(status) method is used to update status of employee");
    // console.warn("project" + JSON.stringify(squadName));

    AsyncStorage.getItem("userName", (err, res) => {
      const userName = res;
      console.log(res);



      // console.log(cropcode);
      NetInfo.fetch().then(state => {
        if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
          console.log(state.type);
          Snackbar.show({
            title: 'No Internet Connection',
            backgroundColor: 'red',
            duration: Snackbar.LENGTH_LONG,
          });
          //for offline project switching start
          this.setState({
            squadName: squadName
          });
          AsyncStorage.setItem('cropcode', squadName);
          this.getOfflineSprints()//Getting the List of offline Sprints
          this.getOfflineActiveSprints("currentsprint") //Getting Current Sprint Backlogs in offline
          this.getBacklogs("unassigned") //For Getting Unassigned Backlogs in offline 
          //for offline project switching end
        } else {

          fetch(API + 'squadLogin.php', {
            method: 'POST',
            headers: {
              Accept: 'application/json',
              'Content-Type': 'application/json',
            },
            body: JSON.stringify({
              username: userName,
              crop: squadName,

            })
          })
            .then((response) => response.json())
            .then((responseJson) => {
              // console.warn(JSON.stringify(responseJson))

              if (responseJson.status == 'TRUE') {
                AsyncStorage.setItem('auth', responseJson.jwt) //store the token information  with exp
                const tokenDetails = jwt_decode(responseJson.jwt);
                console.log(tokenDetails.data)
                AsyncStorage.setItem('roleCount', tokenDetails.data.roleCount)
                // dispatch(setCurrentUser(tokenDetails.data)); //store the user information
                AsyncStorage.setItem('status', tokenDetails.data.empStatus)


                AsyncStorage.setItem('userToken', tokenDetails.data.empId);
                AsyncStorage.setItem('userName', tokenDetails.data.userName);
                AsyncStorage.setItem('emp_role', tokenDetails.data.role);
                AsyncStorage.setItem('cropcode', tokenDetails.data.corp);
                this.onRefresh();

                // this.props.navigation.navigate('UserProfile');
                // console.warn("HI" + empstatus)
                this.setState({

                  squadName: tokenDetails.data.corp,

                });
                //  alert("Project Changed Successfully")
                this.getRequestedIdeas();

              } else {
                //    alert("user already exist");
                log("Warn", "status of employee is not able to update");
              }

            })
            .catch((error) => {
              console.warn(error);
              log("Error", "error in updating status of employee");
            });
        }
      });
    });

  }


  componentWillReceiveProps(nextProps) {
    NetInfo.fetch().then(state => {
      if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
        console.log(state.type);
        Snackbar.show({
          title: 'No Internet Connection',
          backgroundColor: 'red',
          duration: Snackbar.LENGTH_LONG,
        });
        this.getRequestedIdeas(); //For pending subtaskslist from offline
        // this.onRefresh();
      } else {
        //to get the user pending my task list
        this.getRequestedIdeas();
        this.unassignedTasksData();
        // this.onRefresh();
      }
    });

  }
  //get the IdeasList or projects
  async ideas() {

    await AsyncStorage.getItem("emp_role", (err, res) => {
      console.log(res);
      this.setState({ role: res });
    });

    await AsyncStorage.getItem("userToken", (err, res) => {
      console.log(res);
      this.setState({ userToken: res });
    });
    await AsyncStorage.getItem("cropcode", (err, res) => {
      console.log(res);
      this.setState({ cropcode: res });
    });
    this.unassignedTasksData();
    this.getRequestedIdeas(this.state.role, this.state.userToken, this.state.cropcode);
  }

  // //Navigates to TaskChat Screen
  // TaskChat(item, index) {
  //   log("Info", "UserPendingMyTasks:TaskChat(item, index) used to navigate to taskchat")
  //   this.props.navigation.navigate("TaskChat", { taskid: item.taskid, action: "maintask" });
  // }
  //Refresh the data
  onRefresh() {
    // this.setState({
    //   dataSource:[],
    // })
    this.setState({

    })
    // this.getUnassigned();
    this.getRequestedIdeas();
    // this.ideas();
    // this.getRequestedIdeas();
    this.GetStatus();
    // this.getModules();
    this.getActiveSprints();
    this.getSprints1();
    this.getUnactiveSprintTasks();
    this.getUnassigned();
    this.getPending();
    this.unassignedTasksData();
    // this.getMessages();
    // this.currentsprint();

    // this.getRequestedIdeas(this.state.role, this.state.userToken, this.state.cropcode);
  }
  // componentWillReceiveProps(nextProps) {
  //   this.getRequestedIdeas();
  // }
  //getting the Requested projects List
  getRequestedIdeas() {
    // alert("hello")
    AsyncStorage.getItem("cropcode", (err, res) => {
      const cropcode = res;
      AsyncStorage.getItem("userToken", (err, res) => {
        const empId = res;
        AsyncStorage.getItem("emp_role", (err, res) => {
          const emp_role = res;
          AsyncStorage.getItem("moduleId", (err, res) => {
            const moduleId = res;
            AsyncStorage.getItem("projectId", (err, res) => {
              const projectId = res;
              // console.warn(cropcode)
              log("Info", " getRequestedIdeas(role, userToken, cropcode) is used to get all requested projects at admin side");
              NetInfo.fetch().then(state => {
                if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
                  console.log(state.type);
                  log("Warn", "No internet connection");
                  Snackbar.show({
                    title: 'No Internet Connection',
                    backgroundColor: 'red',
                    duration: Snackbar.LENGTH_LONG,
                  });
                  this.getAssignedBacklogs("currentsprint", moduleId) //Getting Current Sprint Backlogs in offline
                } else {
                  // fetch('http://71.40.116.146:2005/getSubtasks.php',
                  // fetch('http://71.40.116.146:2005/getManageMaintasks.php',
                  fetch(API + 'backlogspage.php', {

                    method: 'POST',
                    headers: {
                      Accept: 'application/json',
                      'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({
                      corp: cropcode,
                      empId: empId,
                      action: "currentsprint",
                      sprintId: moduleId,
                      projectId: projectId,

                      // empId: userToken,
                      userType: emp_role
                    })
                  })
                    .then((response) => response.json())
                    .then((responseJson) => {
                      // alert("currentSprints" + JSON.stringify(responseJson.data))
                      console.warn("currentSprints" + JSON.stringify(responseJson.data))
                      if (responseJson.status == 'true') {
                        // console.log(responseJson)
                        this.addBacklogs(responseJson.data, "currentsprint", cropcode, moduleId) //For offline store of currentSprint Backlogs
                        this.setState({
                          isLoading: false,
                          currentsprint: responseJson.data,
                          isFetching: false
                        }, function () {

                        });
                        this.arrayholder = responseJson.data;
                        this.unassignedTasksData();
                      }
                      else {
                        this.arrayholder = [];
                        log("Warn", "no subtasks found");
                        this.setState({
                          isLoading: false,
                          currentsprint: []
                        })
                        this.unassignedTasksData();
                        Snackbar.show({

                          title: 'No Backlogs Found',

                          backgroundColor: '#3BB9FF',
                          duration: Snackbar.LENGTH_LONG,
                        });

                      }

                    })
                    .catch((error) => {
                      console.error(error);
                      log("Error", " subtasks error");
                    });
                }
              });
            });
          });
        });
      });
    });
  }
  //getting the Requested projects List end


  //getting the sprint list for addind maintask
  getSprints1() {
    log("Info", " getEmployees(cropcode) is used for getting the Employees list for addind maintask");
    const { ModuleId } = this.state;
    const { ideaid } = this.state;
    // alert("test")
    AsyncStorage.getItem("cropcode", (err, res) => {
      const cropcode = res;
      AsyncStorage.getItem("projectId", (err, res) => {
        const projectId = res;
        NetInfo.fetch().then(state => {
          if (state.type == "none") {
            console.log(state.type);
            log("Warn", "No internet connection");
            Snackbar.show({
              title: 'No Internet Connection',
              backgroundColor: 'red',
              duration: Snackbar.LENGTH_LONG,
            });
            this.getOfflineSprints(); //Getting Offline Sprint List
          } else {
            fetch(API + 'getUpdateSprint.php',
              {
                method: 'POST',
                headers: {
                  Accept: 'application/json',
                  'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                  crop: cropcode,
                  action: 'getModules',
                  projectId: projectId
                })
              })

              .then((response) => response.json())

              .then((responseJson) => {
                // alert(JSON.stringify(responseJson))
                if (responseJson.status === 'True') {
                  // console.warn("Sprints from active sprint board" + JSON.stringify(responseJson))
                  // alert(JSON.stringify(responseJson))
                  var sprintDetails = [];

                  responseJson.data.map((sprints) => {
                    const [year, month, date] = sprints.startDate.split('-');
                    const [year1, month1, date1] = sprints.targetDate.split('-');
                    return (
                      sprintDetails.push({ 'key': sprints.moduleId, 'epicId': sprints.ideaId, 'label': sprints.moduleDesc })
                    );
                  })

                  this.setState({
                    resource: sprintDetails
                  });
                  this.addOfflineSprints(sprintDetails, cropcode)//Store Sprint List in Offline
                }
              })
              .catch((error) => {
                // alert("test")
                console.error(error);
                log("Error", "requested projects error");
              });
          }
        });
      });
    });

  }



  componentWillUnmount() {
    this.setState({
      text: "",
    })
  }

  //Method for Unassigned task to set
  unassignedTasksData() {
    console.warn("pending" + JSON.stringify(this.state.pendingTasks))

    console.warn("unassignedTasks testing" + JSON.stringify(this.state.unassignedTasks))
    const backlogs = this.state.pendingTasks.concat(this.state.unassignedTasks)

    this.setState({
      backlogs: backlogs,
    })
    // this.onRefresh();
    // alert(JSON.stringify(backlogs))
    console.warn("manageTasks" + JSON.stringify(backlogs))
  }

  // componentWillUpdate() {
  //   console.warn("pending" + JSON.stringify(this.state.pendingTasks))
  //   console.warn("unassignedTasks testing" + JSON.stringify(this.state.unassignedTasks))
  //   const backlogs = this.state.pendingTasks.concat(this.state.unassignedTasks)

  //   this.setState({
  //     backlogs:backlogs,
  //   })
  //   // alert(JSON.stringify(backlogs))
  //   console.warn("manageTasks" + JSON.stringify(backlogs))
  //   // console.log("update..........")
  // }

  //Navigate to Project Modify Screen
  ModifyStory(item, index) {
    console.log(item);
    console.log(index);
    log("Info", "ModifyStory() method is used to move Add Module to Add ModifyUserStory screen");
    this.props.navigation.navigate('ModifyUserStory', { action: 'modify', assigntto: item.assigntto, assignedto: item.assignedTo, projectitle: item.projectitle, ideaid: item.ideano, moduleId: item.moduleId, taskid: item.userstory_id, tasktitle: item.tasktitle, taskdescription: item.taskdescription, acceptanceCriteria: item.acceptanceCriteria, storyPoints: item.storyPoints, priorityLevel: item.priorityLevel });

  }
  //Navigate to Project Reassign Screen
  ReassignStory(item, index) {
    console.log(item);
    console.log(index);
    log("Info", "ReassignStory() method is used to move Add Module to Add ModifyUserStory screen");
    this.props.navigation.navigate('ReassignUserStory', { sprintDesc: item.moduletitle, action: 'reassign', assigntto: item.assigntto, assignedto: item.assignedTo, projectitle: item.projectitle, ideaid: item.ideano, moduleId: item.moduleId, taskid: item.userstory_id, tasktitle: item.tasktitle, taskdescription: item.taskdescription, acceptanceCriteria: item.acceptanceCriteria, storyPoints: item.storyPoints, priorityLevel: item.priorityLevel });

  }
  //Navigate to Add Epic Screen
  AddEpic(item, index) {
    console.log(item);
    console.log(index);
    log("Info", "AddEpic() method is used to move Add Module to Add AddEpic screen");
    this.props.navigation.navigate('AddEpic', { taskid: item.userstory_id, });

  }

  //Navigate to Task Add Screen
  TaskAdd(item, index) {
    console.log(item);
    console.log(index);
    log("Info", "ChangeStatus() method is used to move Add Module to Add TaskAdd screen");
    this.props.navigation.navigate('TaskAdd', { taskid: item.userstory_id, moduleId: item.userstoryModuleId, tasktitle: item.tasktitle, sprintDate: item.targetDate, assignedTo: item.assignedTo });

  }

  //Navigate to ViewTask  Screen
  ViewTask(item, index) {
    console.log(item);
    console.log(index);
    log("Info", "ChangeStatus() method is used to move ViewTask screen");
    this.props.navigation.navigate('ViewTask', { taskId: item.userstory_id, tasktitle: item.tasktitle, sprintDate: item.targetDate, assignedTo: item.assignedTo });

  }


  //Navigate to Change Status Screen
  ChangeStatus(item, index) {
    console.log(item);
    console.log(index);
    log("Info", "ChangeStatus() method is used to move Add Module to Add AddEpic screen");
    this.props.navigation.navigate('ChangeStatus', { sprintDesc: item.moduletitle, taskid: item.userstory_id, activeStatus: item.activeStatus, completeStatus: item.completeStatus, tasktitle: item.tasktitle });

  }

  //Navigate to Change Status Screen
  ChangeStatus1(item, index) {
    console.log(item);
    console.log(index);
    log("Info", "ChangeStatus1() method is used to move Add Module to Add AddEpic screen");
    this.props.navigation.navigate('ChangeStatus1', { sprintDesc: item.moduletitle, taskid: item.userstory_id, activeStatus: item.activeStatus, completeStatus: item.completeStatus, tasktitle: item.tasktitle });

  }

  //Navigate to Add Sprint Screen
  AddSprint(item, index) {
    console.log(item);
    console.log(index);
    log("Info", "UserModifyProject() method is used to move Add Module to Add Sprint screen");
    // this.props.navigation.navigate('AddSprint', {  taskid: item.userstory_id,sprintDesc:item.moduletitle, });
    this.props.navigation.navigate('AddSprint', { sprintDesc: item.moduletitle, taskid: item.userstory_id, assign_to: item.assignedTo, title: item.tasktitle });

  }
  //list seperator
  FlatListItemSeparator = () => {
    return (
      <View
        style={{
          //  height: .5,
          width: "100%",
          backgroundColor: "#000",
        }}
      />
    );
  }
  //List data for Empty
  _listEmptyComponent = () => {
    return (
      <View style={{ width: '90%', height: '80%' }}>
        <Text></Text>
      </View>
    )
  }



  //Searh based on task id ,name,description,and user
  SearchFilterFunction(text) {
    log("Info", "SearchFilterFunction(text) method  used for searching");
    console.log(text);

    const newData = this.arrayholder.filter(function (item) {
      const id = item.id.toUpperCase()
      const id1 = text.toUpperCase()
      // const moduleId = item.moduleId.toUpperCase()
      // const moduleId1 = text.toUpperCase()
      const completeStatus = item.completeStatus.toUpperCase()
      const completeStatus1 = text.toUpperCase()
      const tasktitle = item.tasktitle.toUpperCase()
      const tasktitle1 = text.toUpperCase()
      const acceptanceCriteria = item.acceptanceCriteria.toUpperCase()
      const acceptanceCriteria1 = text.toUpperCase()
      const targettime = item.targettime.toUpperCase()
      const targettime1 = text.toUpperCase()
      const assigntto = item.assigntto.toUpperCase()
      const assigntto1 = text.toUpperCase()
      const assignby = item.assignby.toUpperCase()
      const assignby1 = text.toUpperCase()



      return id.indexOf(id1) > -1 ||
        // moduleId.indexOf(moduleId1) > -1 ||
        completeStatus.indexOf(completeStatus1) > -1 ||
        acceptanceCriteria.indexOf(acceptanceCriteria1) > -1 ||
        targettime.indexOf(targettime1) > -1 ||
        assigntto.indexOf(assigntto1) > -1 ||
        assignby.indexOf(assignby1) > -1 ||

        tasktitle.indexOf(tasktitle1) > -1

    })
    this.setState({
      currentsprint: newData,
      text: text
    })
  }
  //Search data end

  render() {
    if (this.state.isLoading) {
      return (
        <View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
          <DotIndicator color='#00A2C1' />
        </View>
      );

    }


    // const role =  AsyncStorage.getItem('emp_role');
    // alert(JSON.stringify(role))
    let buttonL;

    if (this.state.sprint_status !== "commited") {
      buttonL =
        <TouchableOpacity onPress={() => this.SprintAction(this.state.moduleId, "commit_sprint")} >
          <Text style={{ width: 100, backgroundColor: 'blue', color: 'white', borderRadius: 20, textAlign: 'center' }}>Commit Sprint</Text>
        </TouchableOpacity>
    }
    else {
      buttonL =
        <TouchableOpacity onPress={() => this.SprintAction1(this.state.moduleId, "uncommit_sprint")} >
          <Text style={{ width: 120, backgroundColor: 'blue', color: 'white', borderRadius: 20, textAlign: 'center' }}>Uncommit Sprint</Text>
        </TouchableOpacity>
    }
    // const manageTasks = backlogs;
    return (
      <Container style={{ height: Dimensions.get('window').height }}>
        <NavigationEvents
          onDidFocus={() => this.onRefresh()}
        />

        {/* <Header
          androidStatusBarColor="#00A2C1"
          style={{
            backgroundColor: '#00A2C1',
            height: 50,
            width: Dimensions.get('window').width,
            borderBottomColor: '#ffffff',
            justifyContent: 'space-between',
          }}>
          <View style={{ marginTop: 20 }}>

          </View> */}
        {/* <View style={{ width: 300, borderRadius: 20, height: 45, marginTop: 5, flexDirection: 'row' }}>

            <ModalSelector
              style={{ width: 260, backgroundColor: 'transparent', borderColor: 'transparent', marginLeft: 60 }}
              data={this.state.resource}
              optionContainerStyle={{ backgroundColor: 'white' }}
              // initValue={this.state.sprintDesc}
              onChange={(itemValue) => {
                this.setState({
                  moduleId: itemValue.key,
                  moduleDesc: itemValue.label,

                })
                // }),
                AsyncStorage.setItem('moduleId', itemValue.key);
                // alert("hello"+this.state.moduleId);
                this.getRequestedIdeas()


              }} >

              <View style={{ width: 300, borderRadius: 20, backgroundColor: '#00A2C1', height: 45, flexDirection: 'row' }}>
                <Text style={{ marginTop: 5, color: 'white', width: 80 }}>SPRINT : {this.state.sprintDesc}</Text>

                <Text style={{ marginTop: 5, color: 'white', width: 120, }}>{this.state.moduleDesc}</Text>

                <Icon name="md-chevron-down-outline" size={25} style={{ color: 'white', marginTop: 5, }}
                />
              </View>

            </ModalSelector>


          </View> */}

        {/* </Header> */}


        <Item>
          <NavigationEvents
            onDidFocus={() => this.onRefresh()}
          />
          <Input placeholder="Search"
            onChangeText={(text) => this.SearchFilterFunction(text)} />
          <Icon size={25} style={{ marginLeft: 10 }} name="search" />
        </Item>
        <View style={styles.MainContainer}>
          <Toast ref="toast" />

          <View style={{ height: '90%' }}>
            <Collapse >
              <CollapseHeader >
                <View style={{ flexDirection: 'row' }}>
                  <Text style={{ marginTop: 5, color: 'blue', width: '60%', marginLeft: 5, fontSize: 14, fontWeight: 'bold' }}>ACTIVE SPRINT - {(this.state.cropcode).substring(0, 3).toUpperCase()} : {this.state.moduleDesc}</Text>
                  {this.state.sprint_status === 'commited' &&
                    <Text style={{ width: 80, color: 'orange', paddingTop: 5, fontWeight: 'bold' }}>Committed</Text>
                  }
                </View>
              </CollapseHeader>
              <CollapseBody>
                {(this.state.emp_role !== "Contributor") &&
                  <View style={{ flexDirection: 'row', marginTop: 10, marginBottom: 10, alignItems: 'center', justifyContent: 'center' }}>

                    <TouchableOpacity onPress={() => this.openModal(this.state.moduleDesc, this.state.startDate, this.state.targetDate)} >
                      <Text style={{ width: 60, backgroundColor: '#76C54E', color: 'white', borderRadius: 20, textAlign: 'center' }}>Modify</Text>
                    </TouchableOpacity>
                    <View style={{ width: 5 }}></View>
                    <TouchableOpacity onPress={() => this.deleteAction()} >
                      <Text style={{ width: 60, backgroundColor: '#203B5A', color: 'white', borderRadius: 20, textAlign: 'center' }}>Delete</Text>
                    </TouchableOpacity>
                    <View style={{ width: 5 }}></View>
                    {buttonL}
                    <View style={{ width: 5 }}></View>
                    <TouchableOpacity onPress={() => this.ArchieAction(this.state.moduleId)} >
                      <Text style={{ width: 130, backgroundColor: '#5cb0bd', color: 'white', borderRadius: 20, textAlign: 'center' }}>Move To Archive</Text>
                    </TouchableOpacity>

                  </View>

                }
              </CollapseBody>
            </Collapse>

            <FlatList
              extraData={this.state}
              keyExtractor={this._keyExtractor}
              renderItem={this._renderItem}
              data={this.state.currentsprint}
              onRefresh={() => this.onRefresh()}
              refreshing={this.state.isFetching}
              ItemSeparatorComponent={this.FlatListItemSeparator}
              renderItem={({ item, index }) =>
                <View>
                  <ListItem navigation={this.props.navigation}
                    item={item}
                    empId={this.state.empId}
                    cropcode={this.state.cropcode}
                    ModifyStory={() => this.ModifyStory(item, index)}//For Modify Sprint 
                    ReassignStory={() => this.ReassignStory(item, index)}//For Reassign User Story
                    AddEpic={() => this.AddEpic(item, index)}//For Adding Epic
                    AddSprint={() => this.AddSprint(item, index)}//For Adding Sprint
                    TaskChat={() => this.TaskChat(item, index)}//For TaskLevel Chat
                    ChangeStatus={() => this.ChangeStatus(item, index)}//Change Status
                    ChangeStatus1={() => this.ChangeStatus1(item, index)}//Change Status
                    TaskAdd={() => this.TaskAdd(item, index)}//Task Add
                    ViewTask={() => this.ViewTask(item, index)}//View Task

                  />
                </View>
              }
              keyExtractor={item => item.id}
              ListEmptyComponent={this._listEmptyComponent}
            />


          </View>
          {/* <Text style={{fontSize:25}}>Backlog</Text> */}

          {/* <View style={{ height: '90%' }}>
            <FlatList
              extraData={this.state}
              keyExtractor={this._keyExtractor}
              renderItem={this._renderItem}
              data={this.state.unassignedTasks}
              onRefresh={() => this.onRefresh()}
              refreshing={this.state.isFetching}
              ItemSeparatorComponent={this.FlatListItemSeparator}
              renderItem={({ item, index }) =>
                <View>
                  <ListItem navigation={this.props.navigation}
                    item={item}
                    // AdminProjectInfo={() => this.AdminProjectInfo(item, index)}
                    TaskChat={() => this.TaskChat(item, index)}//For TaskLevel Chat

                  />
                </View>
              }
              keyExtractor={item => item.id}
              ListEmptyComponent={this._listEmptyComponent}
            />
          </View> */}


          <TouchableOpacity onPress={() => this.props.navigation.navigate("AddStory", { moduleid: this.state.moduleId, IdeaId: this.state.ideano })} style={styles.bottomView}>
            <View style={styles.bottomView} >
              <Text style={styles.textStyle}>{ADDMAINTASK}</Text>
            </View>
          </TouchableOpacity>
        </View>


        {/* ModifySprint */}
        <Modal
          offset={this.state.offset}
          closeOnTouchOutside={false}
          open={this.state.open}
          modalDidOpen={this.modalDidOpen}
          modalDidClose={this.modalDidClose}
          style={{ alignItems: "center" }} >
          <View style={{ alignItems: "center", }}>

            <Text>{MODULEINFO}</Text>

            <TextInput placeholder={MODULE_TITLE}
              style={{ height: 40, borderBottomWidth: 1, borderBottomColor: 'black', width: 300, marginTop: 10 }}
              onChangeText={(text) => this.setState({ moduleDesc: text })

              }
              value={this.state.moduleDesc} />
            <Text style={{ color: 'red', alignItems: 'flex-start', alignSelf: 'flex-start', justifyContent: 'flex-start', marginLeft: 25 }}>{this.state.error1}</Text>


          </View>
          <DatePicker
            style={{ textAlign: 'left', marginLeft: 10, borderColor: '#b6b6b6', borderWidth: 1, width: '90%', height: 40, borderRadius: 10, marginTop: 5 }}
            date={this.state.startDate}
            mode="date"
            placeholder="From Date"
            format="MM-DD-YYYY"
            minDate="2020-01-01"
            maxDate="2080-12-31"
            // minDate="01-01-2019"
            // maxDate="01-06-2075"
            confirmBtnText="Ok"
            cancelBtnText=""
            showIcon={false}
            customStyles={{
              dateInput: { borderWidth: 0, borderBottomWidth: 2 },
              placeholderText: { fontSize: 15, color: "#9a73ef" },
              dateText: { textAlign: 'left', fontSize: 15, }
            }}
            onDateChange={(text) => this.setState({ startDate: text })} />
          <DatePicker
            style={{ textAlign: 'left', marginLeft: 10, marginTop: 5, borderColor: '#b6b6b6', borderWidth: 1, width: '90%', height: 40, borderRadius: 10, marginTop: 5 }}
            date={this.state.targetDate}
            mode="date"
            placeholder="To Date"
            format="MM-DD-YYYY"
            minDate="2020-01-01"
            maxDate="2080-12-31"
            // minDate="01-01-2019"
            // maxDate="01-06-2075"
            confirmBtnText="Ok"
            cancelBtnText=""
            showIcon={false}
            customStyles={{
              dateInput: { borderWidth: 0, borderBottomWidth: 2 },
              placeholderText: { fontSize: 15, color: "#9a73ef" },
              dateText: { textAlign: 'left', fontSize: 15, }
            }}
            onDateChange={(text) => this.setState({ targetDate: text })} />
          <View style={{ flexDirection: 'row', alignItems: 'center', justifyContent: 'center', alignSelf: 'center', }}>
            <TouchableOpacity style={styles.opensave} onPress={this.modifyModule.bind(this)} disabled={this.state.itemPressedDisabled}>
              <Text style={{ color: 'white' }}>SAVE</Text>
            </TouchableOpacity>
            <TouchableOpacity style={styles.opencancel} onPress={this.closeModal} >
              <Text style={{ color: 'white' }}>CANCEL</Text>
            </TouchableOpacity>

          </View>

        </Modal>


      </Container>
    );
  }
}

const styles = StyleSheet.create({
  MainContainer:
  {
    flex: 1,
    width: Dimensions.get('window').width,
    height: Dimensions.get('window').height,
  },
  c: {
    backgroundColor: '#f58484',
    marginTop: 10,
    paddingRight: 20,
    margin: "2%",
    borderWidth: 0.8,
    borderColor: 'grey',
    width: '96%',
    borderRadius: 10
  },
  c1: {
    backgroundColor: '#DCDCDC',
    marginTop: 10,
    paddingRight: 20,
    margin: "2%",
    borderWidth: 0.8,
    borderColor: 'grey',
    width: '96%',
    borderRadius: 10
  },
  buttonContainer: {
    width: wp('100%'),
    alignSelf: 'baseline',
    color: '#d2691e',
    backgroundColor: '#fadbd8',
    marginLeft: wp('2%'),
    marginRight: wp('2%'),
  },
  signupButton: {
  },
  subcontainer: {
    flex: 2,
    flexDirection: 'row',
  },
  signUpText0: {
    fontSize: 14,
    color: 'green',
    paddingLeft: 10,
    //fontWeight: "bold",
  },
  signUpText1: {
    fontSize: 14,
    color: 'green',
    // fontWeight: "bold",
  },

  signUpText00: {
    fontSize: 13,
    color: '#323233',
    paddingLeft: 10,

  },
  signUpText00m: {
    fontSize: 13,
    color: '#323233',
    paddingLeft: 10,
    textDecorationLine: 'line-through'
  },
  


  signUpText000: {
    fontSize: 12,
    color: 'black',
    paddingLeft: 10,
  },
  signUpText111: {
    fontSize: 12,
    // paddingBottom: 10,

    color: 'black',

    paddingLeft: -20,
    width: '60%'
  },
  signUpText1101: {
    fontSize: 12,
    // paddingBottom: 10,

    color: 'black',

    paddingLeft: -20,
    width: '70%'
  },
  end: {
    alignItems: 'flex-end',
  },
  end1: {
    flex: 1,
    justifyContent: 'space-between',
    flexDirection: 'row',
  },
  s: {
    justifyContent: 'center',

    backgroundColor: '#ed7070',
    shadowOffset: { width: 50, height: 50 },
    alignItems: 'center',
    width: wp('40%'),
    height: hp('12%'),
    borderTopLeftRadius: 10,
    borderBottomLeftRadius: 10,

  },
  signUpText2: {
    fontSize: 13,
    paddingRight: 10,
    paddingLeft: 13,
    color: 'black',
    justifyContent: 'center',

  },

  bottomView: {
    flex: 1,
    ...Platform.select({
      ios: {
        flexDirection: 'row',
        justifyContent: 'center',
        position: 'absolute',
        height: FOOTER_MAX_HEIGHT,
        bottom: 0,
        left: 0,
        right: 0,
        backgroundColor: 'black',
        alignItems: 'center'
      },
      android: {
        flexDirection: 'row',
        justifyContent: 'center',
        position: 'absolute',
        height: FOOTER_MAX_HEIGHT,
        bottom: 0,
        left: 0,
        right: 0,
        backgroundColor: 'black',
        alignItems: 'center'
      },
    }),
  },


  textStyle: {
    color: '#fff',
    fontSize: 18,
    backgroundColor: '#00a2c1',
    paddingLeft: 10,
    paddingRight: 10,
    // paddingBottom: 5,
    paddingTop: 5,
    borderRadius: 5,
  },

  signUpText02: {
    fontSize: 13,
    paddingRight: 5,
    color: 'green',
    paddingLeft: 13,

    // paddingBottom: 10,
    // fontWeight: 'bold',
  },
  signUpText022: {
    fontSize: 13,
    paddingLeft: 13,
    color: 'green',
    // paddingBottom: 10,
    justifyContent: 'center',

  },
  signUpText002: {
    fontSize: 13,
    paddingLeft: 12,
    // paddingBottom: 10,
    color: 'black'

  },
  signUpText0002: {
    fontSize: 13,
    paddingRight: 45,
    // paddingTop: 20,
    paddingLeft: 13,
    // color: 'red',
    // paddingBottom: 10,
    // fontWeight: 'bold',
    justifyContent: 'center',

  },
  signUpText3: {

    // paddingBottom: 10,
    // paddingLeft: 10,
    fontSize: 13,
    // paddingRight:hp('-10%'),
    paddingRight: 13,
    width: '70%',
    // fontWeight: "bold",
    alignItems: 'center',
    color: '#000000'
  },
  signUpText4: {
    // paddingBottom: 10,
    paddingLeft: 10,
    // fontWeight: 'bold',
    color: '#323233',
    fontSize: 13,
    alignItems: 'center',
  },


  signUpText33: {

    // paddingBottom: 10,
    // paddingLeft: 13,
    fontSize: 13,
    // paddingRight:hp('-10%'),
    paddingRight: 35,
    // fontWeight: 'bold',
    // paddingTop: -10,
    alignItems: 'center',
    // width: wp('80%'),
    color: 'black'

  },
  signUpText44: {
    paddingLeft: 10,
    fontSize: 13,
    alignItems: 'center',
    color: 'black'
  },

  signup: {
    //paddingTop:20,
    color: "#FFF",
  },
  boxone: {
    flex: 1,
    marginTop: 5,

  },
  boxtwo: {
    flex: 1,

  },
  boxthree: {
    flex: 1,

  },
  box: {
    justifyContent: 'space-between',
    flexDirection: 'row',
    position: 'relative',
    // marginBottom: 10,

  },
  box12: {
    marginTop: 10,
    justifyContent: 'space-between',
    flexDirection: 'row',
    position: 'relative',
    paddingRight: 25,
  },
  box1: {
    paddingTop: 10,
    justifyContent: 'space-between',
    flexDirection: 'row',
    position: 'relative',
    paddingRight: 25,
  },
  signUpText: {
    fontSize: 20,
    justifyContent: 'center',


    color: 'white',
    alignSelf: 'center',
  },
  boxheader: {
    //  backgroundColor:'green',
    justifyContent: 'space-between',
    flexDirection: 'column',
    position: 'relative',
    marginBottom: 15,

  },
  opencancel: {
    flex: 1,
    ...Platform.select({
      ios: {
        backgroundColor: 'red', margin: 20, height: 30, alignItems:
          "center", justifyContent: 'center'
      },
      android: {
        backgroundColor: 'red', margin: 20, height: 30, alignItems:
          "center", justifyContent: 'center'
      },
    }),
  },
  opensave: {
    flex: 1,
    ...Platform.select({
      ios: {
        backgroundColor: 'green', margin: 20, height: 30, alignItems:
          "center", justifyContent: 'center'
      },
      android: {
        backgroundColor: 'green', margin: 20, height: 30, alignItems:
          "center", justifyContent: 'center'
      },
    }),
  },

});
